@@ -15,7 +15,7 @@
 // along with this program; if not, write to the Free Software Foundation,
 // Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 
-// $Id: Py_CreatorClient.cpp,v 1.37 2007-12-02 23:49:05 alriddoch Exp $
+// $Id: Py_CreatorClient.cpp,v 1.38 2007-12-27 03:31:48 alriddoch Exp $
 
 #include "Py_CreatorClient.h"
 
@@ -31,7 +31,7 @@
 #include "rulesets/Py_Map.h"
 
 #include "common/debug.h"
-#include "common/inheritance.h"
+#include "common/TypeNode.h"
 
 using Atlas::Message::Element;
 using Atlas::Message::MapType;
