@@ -15,6 +15,8 @@
 // along with this program; if not, write to the Free Software Foundation,
 // Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 
+// $Id: PropertyManager.h,v 1.6 2007-09-22 15:34:04 alriddoch Exp $
+
 #ifndef COMMON_PROPERTY_MANAGER_H
 #define COMMON_PROPERTY_MANAGER_H
 
@@ -23,8 +25,10 @@
 class Entity;
 class PropertyBase;
 
+/// \brief Base class for classes that handle creating Entity properties.
 class PropertyManager {
   protected:
+    /// \brief Singleton instance pointer for any subclass
     static PropertyManager * m_instance;
 
     PropertyManager();
@@ -32,8 +36,14 @@ class PropertyManager {
   public:
     virtual ~PropertyManager();
 
-    virtual PropertyBase * addProperty(Entity *, const std::string & name) = 0;
+    /// \brief Add a new named property to an Entity
+    ///
+    /// @param entity Entity to which the Property should be added.
+    /// @param name a string giving the name of the property.
+    virtual PropertyBase * addProperty(Entity * entity,
+                                       const std::string & name) = 0;
 
+    /// \brief Return the registered singleton instance of any subclass
     static PropertyManager * instance() {
         return m_instance;
     }
