@@ -15,11 +15,23 @@
 // along with this program; if not, write to the Free Software Foundation,
 // Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 
+// $Id: const.h,v 1.55 2007-10-01 03:40:05 alriddoch Exp $
+
 #ifndef COMMON_CONST_H
 #define COMMON_CONST_H
 
 namespace consts {
 
+  /// \defgroup Constants Global Configuration Constants
+  ///
+  /// These constants defined in common/config.h control the configuration
+  /// of some aspects of the server which cannot be changed at runtime.
+  /// Most commonly they are made constant for performance reasons, though
+  /// sometimes it is because a change in the value at runtime could give
+  /// confusing or undefined results.
+
+  // @{
+
   /// \brief Should python code emit thinking ops
   static const int debug_thinking = 0;
   /// \brief Debug level for python code
@@ -38,24 +50,13 @@ namespace consts {
   static const float square_basic_tick = basic_tick * basic_tick;
   static const float square_base_velocity = base_velocity * base_velocity;
 
-  /// \brief Are ranges for broadcast enabled.
-  static const bool enable_ranges = true;
-  /// \brief Range of broadcast sight ops
-  static const float sight_range = 26.0;
-  static const float square_sight_range = (sight_range * sight_range);
   /// \brief sin() of minimum angle subtended by visible object
   static const float sight_factor = 0.06;
   static const float square_sight_factor = (sight_factor * sight_factor);
-  /// \brief Range of broadcast sound ops
-  static const float hearing_range = 13.0;
-  /// \brief Can things be omnipresent
-  static const bool enable_omnipresence = false;
   /// \brief What is the minimum size of an object when calculating visibility
   static const float minSqrBoxSize = 0.25f;
   /// \brief What is the minimum size of an object when calculating visibility
   static const float minBoxSize = 0.5f;
-  /// \brief Should we use a database
-  static const bool enable_database = true;
   /// \brief Should world state be persistent
   static const bool enable_persistence = false;
 
@@ -71,7 +72,10 @@ namespace consts {
   extern const char * buildTime;
   /// \brief Date this server was built
   extern const char * buildDate;
+  /// \brief Build number of this build, derived from ChangeLog RCS revision
+  extern const int buildId;
 
+  // @}
 }
 
 #endif // COMMON_CONST_H
