@@ -15,12 +15,14 @@
 // along with this program; if not, write to the Free Software Foundation,
 // Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 
-// $Id: inheritance.cpp,v 1.37 2007-12-07 00:44:08 alriddoch Exp $
+// $Id: inheritance.cpp,v 1.41 2008-01-13 01:32:55 alriddoch Exp $
 
 #include "inheritance.h"
 
 #include "log.h"
+#include "TypeNode.h"
 #include "compose.hpp"
+#include "OperationRouter.h"
 
 #include <Atlas/Objects/Operation.h>
 
@@ -57,10 +59,6 @@ using Atlas::Objects::Operation::Error;
 using Atlas::Objects::Operation::Use;
 using Atlas::Objects::Operation::Wield;
 
-TypeNode::TypeNode() : m_parent(0)
-{
-}
-
 Inheritance * Inheritance::m_instance = NULL;
 
 Root atlasOpDefinition(const std::string & name, const std::string & parent)
@@ -140,7 +138,7 @@ OpNo Inheritance::opEnumerate(const std::string & parent) const
     }
 }
 
-OpNo Inheritance::opEnumerate(const Operation & op) const
+OpNo Inheritance::opEnumerate(const Atlas::Objects::Operation::RootOperation & op) const
 {
     return op->getClassNo();
 }
@@ -173,7 +171,7 @@ bool Inheritance::hasClass(const std::string & parent)
 }
 
 TypeNode * Inheritance::addChild(const Root & obj,
-                                 const Atlas::Message::MapType & defaults)
+                                 const PropertyDict & defaults)
 {
     const std::string & child = obj->getId();
     const std::string & parent = obj->getParents().front();
@@ -256,58 +254,58 @@ void installStandardObjects()
 
     i.addChild(atlasOpDefinition("root_operation", "root"));
     i.addChild(atlasOpDefinition("action", "root_operation"));
-    i.opInstall("action", OP_ACTION);
+    i.opInstall("action", Atlas::Objects::Operation::ACTION_NO);
     i.addChild(atlasOpDefinition("create", "action"));
-    i.opInstall("create", OP_CREATE);
+    i.opInstall("create", Atlas::Objects::Operation::CREATE_NO);
     i.addChild(atlasOpDefinition("delete", "action"));
-    i.opInstall("delete", OP_DELETE);
+    i.opInstall("delete", Atlas::Objects::Operation::DELETE_NO);
     i.addChild(atlasOpDefinition("info", "root_operation"));
-    i.opInstall("info", OP_INFO);
+    i.opInstall("info", Atlas::Objects::Operation::INFO_NO);
     i.addChild(atlasOpDefinition("set", "action"));
-    i.opInstall("set", OP_SET);
+    i.opInstall("set", Atlas::Objects::Operation::SET_NO);
     i.addChild(atlasOpDefinition("get", "action"));
-    i.opInstall("get", OP_GET);
+    i.opInstall("get", Atlas::Objects::Operation::GET_NO);
     i.addChild(atlasOpDefinition("perception", "info"));
     i.addChild(atlasOpDefinition("error", "info"));
-    i.opInstall("error", OP_ERROR);
+    i.opInstall("error", Atlas::Objects::Operation::ERROR_NO);
     i.addChild(atlasOpDefinition("combine", "create"));
-    i.opInstall("combine", OP_COMBINE);
+    i.opInstall("combine", Atlas::Objects::Operation::COMBINE_NO);
     i.addChild(atlasOpDefinition("divide", "create"));
-    i.opInstall("divide", OP_DIVIDE);
+    i.opInstall("divide", Atlas::Objects::Operation::DIVIDE_NO);
     i.addChild(atlasOpDefinition("communicate", "create"));
     i.addChild(atlasOpDefinition("move", "set"));
-    i.opInstall("move", OP_MOVE);
+    i.opInstall("move", Atlas::Objects::Operation::MOVE_NO);
     i.addChild(atlasOpDefinition("affect", "set"));
-    i.opInstall("affect", OP_MOVE);
+    i.opInstall("affect", Atlas::Objects::Operation::MOVE_NO);
     i.addChild(atlasOpDefinition("perceive", "get"));
     i.addChild(atlasOpDefinition("login", "get"));
-    i.opInstall("login", OP_LOGIN);
+    i.opInstall("login", Atlas::Objects::Operation::LOGIN_NO);
     i.addChild(atlasOpDefinition("logout", "login"));
-    i.opInstall("logout", OP_LOGOUT);
+    i.opInstall("logout", Atlas::Objects::Operation::LOGOUT_NO);
     i.addChild(atlasOpDefinition("sight", "perception"));
-    i.opInstall("sight", OP_SIGHT);
+    i.opInstall("sight", Atlas::Objects::Operation::SIGHT_NO);
     i.addChild(atlasOpDefinition("sound", "perception"));
-    i.opInstall("sound", OP_SOUND);
+    i.opInstall("sound", Atlas::Objects::Operation::SOUND_NO);
     i.addChild(atlasOpDefinition("smell", "perception"));
     i.addChild(atlasOpDefinition("feel", "perception"));
     i.addChild(atlasOpDefinition("imaginary", "action"));
-    i.opInstall("imaginary", OP_IMAGINARY);
+    i.opInstall("imaginary", Atlas::Objects::Operation::IMAGINARY_NO);
     i.addChild(atlasOpDefinition("talk", "communicate"));
-    i.opInstall("talk", OP_TALK);
+    i.opInstall("talk", Atlas::Objects::Operation::TALK_NO);
     i.addChild(atlasOpDefinition("look", "perceive"));
-    i.opInstall("look", OP_LOOK);
+    i.opInstall("look", Atlas::Objects::Operation::LOOK_NO);
     i.addChild(atlasOpDefinition("listen", "perceive"));
     i.addChild(atlasOpDefinition("sniff", "perceive"));
     i.addChild(atlasOpDefinition("touch", "perceive"));
-    i.opInstall("touch", OP_TOUCH);
+    i.opInstall("touch", Atlas::Objects::Operation::TOUCH_NO);
     i.addChild(atlasOpDefinition("appearance", "sight"));
-    i.opInstall("appearance", OP_APPEARANCE);
+    i.opInstall("appearance", Atlas::Objects::Operation::APPEARANCE_NO);
     i.addChild(atlasOpDefinition("disappearance", "sight"));
-    i.opInstall("disappearance", OP_DISAPPEARANCE);
+    i.opInstall("disappearance", Atlas::Objects::Operation::DISAPPEARANCE_NO);
     i.addChild(atlasOpDefinition("use", "action"));
-    i.opInstall("use", OP_USE);
+    i.opInstall("use", Atlas::Objects::Operation::USE_NO);
     i.addChild(atlasOpDefinition("wield", "set"));
-    i.opInstall("wield", OP_WIELD);
+    i.opInstall("wield", Atlas::Objects::Operation::WIELD_NO);
 
 
 
