@@ -15,7 +15,7 @@
 // along with this program; if not, write to the Free Software Foundation,
 // Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 
-// $Id: log.cpp,v 1.27 2007-12-07 00:27:14 alriddoch Exp $
+// $Id: log.cpp,v 1.29 2008-04-29 15:33:59 alriddoch Exp $
 
 #ifdef HAVE_CONFIG_H
 #include "config.h"
@@ -28,6 +28,8 @@
 #include <iostream>
 #include <fstream>
 
+#include <cstring>
+
 extern "C" {
 #ifdef HAVE_SYSLOG_H
   #include <syslog.h>
@@ -146,7 +148,7 @@ void log(LogLevel lvl, const std::string & msg)
     {
 #endif // HAVE_SYSLOG
 
-        char * type;
+        const char * type;
         switch (lvl) {
             case INFO:
                 type = "INFO";
@@ -184,7 +186,7 @@ void logEvent(LogEvent lev, const std::string & msg)
         return;
     }
 
-    char * type;
+    const char * type;
     switch (lev) {
         case START:
             type = "START";
