@@ -15,18 +15,31 @@
 // along with this program; if not, write to the Free Software Foundation,
 // Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 
+// $Id: log.h,v 1.19 2007-07-29 12:22:58 alriddoch Exp $
+
 #ifndef COMMON_LOG_H
 #define COMMON_LOG_H
 
+#include <string>
+
+// Some systems pollute the namespace with defines of ERROR and perhaps
+// others.
+#undef ERROR
+
 typedef enum log_level { INFO, SCRIPT, NOTICE,
-                         WARNING, ERROR, SCRIPT_ERROR, CRITICAL } LogLevel;
+                         WARNING, CYLOG_ERROR, ERROR = CYLOG_ERROR,
+                         SCRIPT_ERROR,
+                         CRITICAL } LogLevel;
 
 typedef enum log_event { START, STOP, CONNECT, DISCONNECT, LOGIN, LOGOUT,
                          TAKE_CHAR, DROP_CHAR } LogEvent;
 
 void initLogger();
-void log(LogLevel, const char * msg);
-void logEvent(LogEvent, const char * msg);
+void rotateLogger();
+void log(LogLevel, const std::string & msg);
+void logEvent(LogEvent, const std::string & msg);
 void logSysError(LogLevel);
 
+bool testEventLog(const char * path);
+
 #endif // COMMON_LOG_H
