@@ -15,8 +15,10 @@
 // along with this program; if not, write to the Free Software Foundation,
 // Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 
+// $Id: newid.cpp,v 1.6 2007-02-20 00:52:42 alriddoch Exp $
+
 #include "common/id.h"
-#include "common/const.h"
+#include "common/globals.h"
 #include "common/Database.h"
 
 #include <assert.h>
@@ -25,7 +27,7 @@ static long idGenerator = 0;
 
 long newId(std::string & id)
 {
-    if (consts::enable_database) {
+    if (database_flag) {
         return Database::instance()->newId(id);
     } else {
         static char buf[32];
