@@ -15,81 +15,63 @@
 // along with this program; if not, write to the Free Software Foundation,
 // Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 
-// $Id: op_switch.h,v 1.36 2007-11-23 16:18:18 alriddoch Exp $
+// $Id: op_switch.h,v 1.39 2008-03-26 01:34:16 alriddoch Exp $
 
 #ifndef COMMON_OP_SWITCH_H
 #define COMMON_OP_SWITCH_H
 
 #define OP_SWITCH(_op, _op_no, _result, _prefix) \
     switch (_op_no) { \
-        case OP_APPEARANCE: \
+        case Atlas::Objects::Operation::APPEARANCE_NO: \
             _prefix ## AppearanceOperation(_op, _result); \
             break; \
-        case OP_COMBINE: \
+        case Atlas::Objects::Operation::COMBINE_NO: \
             _prefix ## CombineOperation(_op, _result); \
             break; \
-        case OP_CREATE: \
+        case Atlas::Objects::Operation::CREATE_NO: \
             _prefix ## CreateOperation(_op, _result); \
             break; \
-        case OP_DELETE: \
+        case Atlas::Objects::Operation::DELETE_NO: \
             _prefix ## DeleteOperation(_op, _result); \
             break; \
-        case OP_DISAPPEARANCE: \
+        case Atlas::Objects::Operation::DISAPPEARANCE_NO: \
             _prefix ## DisappearanceOperation(_op, _result); \
             break; \
-        case OP_DIVIDE: \
+        case Atlas::Objects::Operation::DIVIDE_NO: \
             _prefix ## DivideOperation(_op, _result); \
             break; \
-        case OP_ERROR: \
-            _prefix ## ErrorOperation(_op, _result); \
-            break; \
-        case OP_GET: \
-            _prefix ## GetOperation(_op, _result); \
-            break; \
-        case OP_IMAGINARY: \
+        case Atlas::Objects::Operation::IMAGINARY_NO: \
             _prefix ## ImaginaryOperation(_op, _result); \
             break; \
-        case OP_INFO: \
-            _prefix ## InfoOperation(_op, _result); \
-            break; \
-        case OP_LOGIN: \
-            _prefix ## LoginOperation(_op, _result); \
-            break; \
-        case OP_LOGOUT: \
-            _prefix ## LogoutOperation(_op, _result); \
-            break; \
-        case OP_LOOK: \
+        case Atlas::Objects::Operation::LOOK_NO: \
             _prefix ## LookOperation(_op, _result); \
             break; \
-        case OP_MOVE: \
+        case Atlas::Objects::Operation::MOVE_NO: \
             _prefix ## MoveOperation(_op, _result); \
             break; \
-        case OP_SET: \
+        case Atlas::Objects::Operation::SET_NO: \
             _prefix ## SetOperation(_op, _result); \
             break; \
-        case OP_SIGHT: \
+        case Atlas::Objects::Operation::SIGHT_NO: \
             _prefix ## SightOperation(_op, _result); \
             break; \
-        case OP_SOUND: \
+        case Atlas::Objects::Operation::SOUND_NO: \
             _prefix ## SoundOperation(_op, _result); \
             break; \
-        case OP_TALK: \
+        case Atlas::Objects::Operation::TALK_NO: \
             _prefix ## TalkOperation(_op, _result); \
             break; \
-        case OP_TOUCH: \
+        case Atlas::Objects::Operation::TOUCH_NO: \
             _prefix ## TouchOperation(_op, _result); \
             break; \
-        case OP_USE: \
-            _prefix ## UseOperation(_op, _result); \
-            break; \
-        case OP_WIELD: \
+        case Atlas::Objects::Operation::WIELD_NO: \
             _prefix ## WieldOperation(_op, _result); \
             break; \
         case OP_INVALID: \
             break; \
         default: \
-            if (_op_no == Atlas::Objects::Operation::ADD_NO) { \
-                _prefix ## AddOperation(_op, _result); \
+            if (_op_no == Atlas::Objects::Operation::ACTUATE_NO) { \
+                _prefix ## ActuateOperation(_op, _result); \
             } else if (_op_no == Atlas::Objects::Operation::ATTACK_NO) { \
                 _prefix ## AttackOperation(_op, _result); \
             } else if (_op_no == Atlas::Objects::Operation::EAT_NO) { \
@@ -103,29 +85,29 @@
             } else if (_op_no == Atlas::Objects::Operation::UPDATE_NO) { \
                 _prefix ## UpdateOperation(_op, _result); \
             } else { \
-                _prefix ## OtherOperation(_op, _result); \
+                /* ERROR */ \
             } \
             break; \
     }
 
 #define POLL_OP_SWITCH(_op, _op_no, _prefix) \
     switch (_op_no) { \
-        case OP_APPEARANCE: \
+        case Atlas::Objects::Operation::APPEARANCE_NO: \
             return _prefix ## AppearanceOperation(_op); \
             break; \
-        case OP_DISAPPEARANCE: \
+        case Atlas::Objects::Operation::DISAPPEARANCE_NO: \
             return _prefix ## DisappearanceOperation(_op); \
             break; \
-        case OP_SIGHT: \
+        case Atlas::Objects::Operation::SIGHT_NO: \
             return _prefix ## SightOperation(_op); \
             break; \
-        case OP_SOUND: \
+        case Atlas::Objects::Operation::SOUND_NO: \
             return _prefix ## SoundOperation(_op); \
             break; \
-        case OP_TOUCH: \
+        case Atlas::Objects::Operation::TOUCH_NO: \
             return _prefix ## TouchOperation(_op); \
             break; \
-        case OP_ERROR: \
+        case Atlas::Objects::Operation::ERROR_NO: \
             return _prefix ## ErrorOperation(_op); \
             break; \
         case OP_INVALID: \
@@ -144,16 +126,16 @@
 
 #define SUB_OP_SWITCH(_op, _sub_op_no, _result, _prefix) \
     switch (_sub_op_no) { \
-        case OP_CREATE: \
+        case Atlas::Objects::Operation::CREATE_NO: \
             _prefix ## CreateOperation(_op, _result); \
             break; \
-        case OP_DELETE: \
+        case Atlas::Objects::Operation::DELETE_NO: \
             _prefix ## DeleteOperation(_op, _result); \
             break; \
-        case OP_MOVE: \
+        case Atlas::Objects::Operation::MOVE_NO: \
             _prefix ## MoveOperation(_op, _result); \
             break; \
-        case OP_SET: \
+        case Atlas::Objects::Operation::SET_NO: \
             _prefix ## SetOperation(_op, _result); \
             break; \
         case OP_INVALID: \
