@@ -15,6 +15,8 @@
 // along with this program; if not, write to the Free Software Foundation,
 // Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 
+// $Id: ArithmeticScript.h,v 1.6 2006-12-24 17:18:55 alriddoch Exp $
+
 #ifndef RULESETS_ARITHMETIC_SCRIPT_H
 #define RULESETS_ARITHMETIC_SCRIPT_H
 
@@ -27,7 +29,11 @@ class ArithmeticScript {
   public:
     virtual ~ArithmeticScript();
 
-    virtual int attribute(const std::string &, float &) = 0;
+    /// \brief Retrieve a named value from the arithmetic model
+    ///
+    /// @param name of the value to be retrieved
+    /// @param val value returned by the model
+    virtual int attribute(const std::string & name, float & val) = 0;
 };
 
 #endif // RULESETS_ARITHMETIC_SCRIPT_H
