@@ -15,7 +15,7 @@
 // along with this program; if not, write to the Free Software Foundation,
 // Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 
-// $Id: BaseMind.cpp,v 1.110 2007-12-04 00:04:00 alriddoch Exp $
+// $Id: BaseMind.cpp,v 1.113 2008-01-26 17:43:21 alriddoch Exp $
 
 #include "BaseMind.h"
 
@@ -49,9 +49,9 @@ static const bool debug_flag = false;
 /// @param id String identifier
 /// @param intId Integer identifier
 /// @param body_name The name attribute of the body this mind controls
-BaseMind::BaseMind(const std::string & id, long intId) : MemEntity(id, intId),
-                                                         m_map(m_script),
-                                                         m_isAwake(true)
+BaseMind::BaseMind(const std::string & id, long intId) :
+          Identified(id, intId),
+          MemEntity(id, intId), m_map(m_script), m_isAwake(true)
 {
     setVisible(true);
     m_map.addEntity(this);
@@ -266,13 +266,29 @@ void BaseMind::operation(const Operation & op, OpVector & res)
     m_time.update((int)op->getSeconds());
     m_map.check(op->getSeconds());
     m_map.getAdd(op->getFrom());
-    Operation look(0);
     m_map.sendLooks(res);
     m_script->operation("call_triggers", op, res);
     if (m_script->operation(op->getParents().front(), op, res) != 0) {
         return;
     }
-    callOperation(op, res);
+    const OpNo op_no = op->getClassNo();
+    switch (op_no) {
+        case Atlas::Objects::Operation::SIGHT_NO:
+            SightOperation(op, res);
+            break;
+        case Atlas::Objects::Operation::SOUND_NO:
+            SoundOperation(op, res);
+            break;
+        case Atlas::Objects::Operation::APPEARANCE_NO:
+            AppearanceOperation(op, res);
+            break;
+        case Atlas::Objects::Operation::DISAPPEARANCE_NO:
+            DisappearanceOperation(op, res);
+            break;
+        default:
+            // ERROR
+            break;
+    }
 }
 
 void BaseMind::callSightOperation(const Operation & op,
