@@ -15,7 +15,7 @@
 // along with this program; if not, write to the Free Software Foundation,
 // Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 
-// $Id: Character.cpp,v 1.307 2007-12-03 23:18:51 alriddoch Exp $
+// $Id: Character.cpp,v 1.323 2008-05-28 19:42:36 alriddoch Exp $
 
 #include "Character.h"
 
@@ -34,12 +34,12 @@
 #include "common/debug.h"
 #include "common/globals.h"
 #include "common/log.h"
-#include "common/inheritance.h"
+#include "common/TypeNode.h"
 #include "common/serialno.h"
 #include "common/compose.hpp"
 #include "common/PropertyManager.h"
 
-#include "common/Add.h"
+#include "common/Actuate.h"
 #include "common/Attack.h"
 #include "common/Eat.h"
 #include "common/Nourish.h"
@@ -99,6 +99,8 @@ const double Character::energyLaidDown = 0.1;
 // Ammount of weight gained as a result. High for Acorn.
 const double Character::weightGain = 0.5;
 
+static const std::string RIGHT_HAND_WIELD = "right_hand_wield";
+static const std::string OUTFIT = "outfit";
 
 /// \brief Calculate how the Characters metabolism has affected it in the
 /// last tick
@@ -221,14 +223,17 @@ void Character::wieldDropped()
 LocatedEntity * Character::findInContains(LocatedEntity * ent,
                                           const std::string & id)
 {
-    LocatedEntitySet::const_iterator I = ent->m_contains.begin();
-    LocatedEntitySet::const_iterator Iend = ent->m_contains.end();
+    if (ent->m_contains == 0) {
+        return 0;
+    }
+    LocatedEntitySet::const_iterator I = ent->m_contains->begin();
+    LocatedEntitySet::const_iterator Iend = ent->m_contains->end();
     for (; I != Iend; ++I) {
         LocatedEntity * child = *I;
         if (child->getId() == id) {
             return *I;
         }
-        if (!child->m_contains.empty()) {
+        if (child->m_contains != 0 && !child->m_contains->empty()) {
             LocatedEntity * found = findInContains(child, id);
             if (found != 0) {
                 return found;
@@ -252,20 +257,21 @@ LocatedEntity * Character::findInInventory(const std::string & id)
 /// @param id String identifier
 /// @param intId Integer identifier
 Character::Character(const std::string & id, long intId) :
-                                            Character_parent(id, intId),
-                                            m_statistics(*this),
-                                            m_movement(*new Pedestrian(*this)),
-                                            m_task(0), m_isAlive(true),
-                                            m_stamina(1.),
-                                            m_maxMass(100),
-                                            m_mind(0), m_externalMind(0)
+           Identified(id, intId),
+           Character_parent(id, intId),
+               m_statistics(*this),
+               m_movement(*new Pedestrian(*this)),
+               m_task(0), m_isAlive(true),
+               m_stamina(1.),
+               m_maxMass(100),
+               m_mind(0), m_externalMind(0)
 {
     m_location.setBBox(BBox(WFMath::Point<3>(-0.25, -0.25, 0),
                             WFMath::Point<3>(0.25, 0.25, 2)));
 
     m_properties["stamina"] = new Property<double>(m_stamina, 0);
     m_properties["statistics"] = new StatisticsProperty(m_statistics, 0);
-    m_properties["right_hand_wield"] = new EntityProperty(m_rightHandWield);
+    m_properties[RIGHT_HAND_WIELD] = new EntityProperty;
 }
 
 Character::~Character()
@@ -506,18 +512,25 @@ void Character::NourishOperation(const Operation & op, OpVector & res)
 void Character::WieldOperation(const Operation & op, OpVector & res)
 {
     if (op->getArgs().empty()) {
-        // Wield nothing
-        if (m_rightHandWieldConnection.connected()) {
-            m_rightHandWieldConnection.disconnect();
+        EntityProperty * rhw = getSpecificProperty<EntityProperty>(RIGHT_HAND_WIELD);
+        if (rhw == 0) {
+            return;
         }
 
-        m_rightHandWield = EntityRef(0);
+        rhw->data() = EntityRef(0);
+        // FIXME Remove the property?
+
+        // FIXME Make sure we stop wielding if the container changes,
+        // but connections are cleared, and don't build up.
+        // if (m_rightHandWieldConnection.connected()) {
+            // m_rightHandWieldConnection.disconnect();
+        // }
 
         Update update;
         update->setTo(getId());
         Anonymous update_arg;
         update_arg->setId(getId());
-        update_arg->setAttr("right_hand_wield", "");
+        update_arg->setAttr(RIGHT_HAND_WIELD, "");
         update->setArgs1(update_arg);
         res.push_back(update);
 
@@ -535,8 +548,7 @@ void Character::WieldOperation(const Operation & op, OpVector & res)
         return;
     }
 
-    LocatedEntitySet::const_iterator K = m_contains.find(item);
-    if (K == m_contains.end()) {
+    if (m_contains == 0 || m_contains->find(item) == m_contains->end()) {
         error(op, "Wield arg is not in inventory", res, getId());
         return;
     }
@@ -549,20 +561,11 @@ void Character::WieldOperation(const Operation & op, OpVector & res)
         debug(std::cout << "Got wield for a garment" << std::endl << std::flush;);
         
         if (worn_attr.isString()) {
-            OutfitProperty * outfit;
-            PropertyBase * prop = getProperty("outfit");
-            if (prop != 0) {
-                outfit = dynamic_cast<OutfitProperty*>(prop);
-                assert(outfit != 0);
-            } else {
-                // FIXME #8 really hacked in, should use manager
-                outfit = new OutfitProperty;
-                m_properties["outfit"] = outfit;
-            }
+            OutfitProperty * outfit = requireSpecificProperty<OutfitProperty>(OUTFIT);
             outfit->wear(this, worn_attr.String(), item);
             outfit->cleanUp();
 
-            update_arg->setAttr("outfit", MapType());
+            update_arg->setAttr(OUTFIT, MapType());
         } else {
             log(WARNING, "Got clothing with non-string worn attribute.");
         }
@@ -574,17 +577,19 @@ void Character::WieldOperation(const Operation & op, OpVector & res)
     } else {
         debug(std::cout << "Got wield for a tool" << std::endl << std::flush;);
 
-        if (m_rightHandWieldConnection.connected()) {
-            m_rightHandWieldConnection.disconnect();
-        }
+        EntityProperty * rhw = requireSpecificProperty<EntityProperty>(RIGHT_HAND_WIELD);
+        // FIXME Make sure we don't stay linked to the previous wielded
+        // tool.
+        // if (m_rightHandWieldConnection.connected()) {
+            // m_rightHandWieldConnection.disconnect();
+        // }
 
         // The value is ignored by the update handler, but should be the
         // right type.
-        update_arg->setAttr("right_hand_wield", item->getId());
-        // setAttr("right_hand_wield", item->getId());
-        m_rightHandWield = EntityRef(item);
+        update_arg->setAttr(RIGHT_HAND_WIELD, item->getId());
+        rhw->data() = EntityRef(item);
 
-        m_rightHandWieldConnection = item->containered.connect(sigc::mem_fun(this, &Character::wieldDropped));
+        item->containered.connect(sigc::mem_fun(this, &Character::wieldDropped));
 
         debug(std::cout << "Wielding " << item->getId() << std::endl << std::flush;);
     }
@@ -659,28 +664,152 @@ void Character::AttackOperation(const Operation & op, OpVector & res)
     }
 }
 
-/// \brief Filter a Login operation coming from the mind
+/// \brief Filter an Actuate operation coming from the mind
 ///
 /// @param op The operation to be filtered.
 /// @param res The filtered result is returned here.
-void Character::mindLoginOperation(const Operation & op, OpVector & res)
+void Character::mindActuateOperation(const Operation & op, OpVector & res)
 {
-}
+    debug(std::cout << "Got Acuate op from mind" << std::endl << std::flush;);
 
-/// \brief Filter a Logout operation coming from the mind
-///
-/// @param op The operation to be filtered.
-/// @param res The filtered result is returned here.
-void Character::mindLogoutOperation(const Operation & op, OpVector & res)
-{
-}
+    const std::vector<Root> & args = op->getArgs();
+    if (args.empty()) {
+        error(op, "Character::mindActuateOp No arg.", res, getId());
+        return;
+    }
 
-/// \brief Filter a Add operation coming from the mind
-///
-/// @param op The operation to be filtered.
-/// @param res The filtered result is returned here.
-void Character::mindAddOperation(const Operation & op, OpVector & res)
-{
+
+    RootEntity entity_arg(0);
+
+    assert(!entity_arg.isValid());
+
+    std::string op_type;
+
+    // Look at Actuate args. If arg is an entity, this is the target.
+    // If arg is an operation, this is the operation to be used, and the
+    // sub op arg may be an entity specifying target. If op to be used is
+    // specified, this is checked against the ops permitted by this tool.
+    const Root & arg = args.front();
+    const std::string & argtype = arg->getObjtype();
+    if (argtype == "op") {
+        if (!arg->hasAttrFlag(Atlas::Objects::PARENTS_FLAG) ||
+            (arg->getParents().empty())) {
+            error(op, "Use arg op has malformed parents", res, getId());
+            return;
+        }
+        op_type = arg->getParents().front();
+        debug(std::cout << "Got op type " << op_type << " from arg"
+                        << std::endl << std::flush;);
+        // Check against valid ops
+        Operation arg_op = smart_dynamic_cast<Operation>(arg);
+        if (!arg_op.isValid()) {
+            error(op, "Use op arg is a malformed op", res, getId());
+            return;
+        }
+
+        const std::vector<Root> & arg_op_args = arg_op->getArgs();
+        if (!arg_op_args.empty()) {
+            entity_arg = smart_dynamic_cast<RootEntity>(arg_op_args.front());
+            if (!entity_arg.isValid()) {
+                error(op, "Use op target is malformed", res, getId());
+                return;
+            }
+        }
+    } else if (argtype == "obj") {
+        entity_arg = smart_dynamic_cast<RootEntity>(arg);
+        if (!entity_arg.isValid()) {
+            error(op, "Use target is malformed", res, getId());
+            return;
+        }
+    } else {
+        error(op, "Use arg has unknown objtype", res, getId());
+        return;
+    }
+
+    if (!entity_arg.isValid()) {
+        error(op, "Character::mindActuateOperation No target specified", res, getId());
+        return;
+    }
+
+    if (!entity_arg->hasAttrFlag(Atlas::Objects::ID_FLAG)) {
+        error(op, "Character::mindActuateOperation Target entity has no ID", res, getId());
+        return;
+    }
+
+    if (op_type.empty()) {
+        error(op, "Character::mindActuateOperation Unable to determine op type for tool", res, getId());
+        return;
+    }
+
+    Entity * device = BaseWorld::instance().getEntity(entity_arg->getId());
+
+    Element deviceOpAttr;
+    std::set<std::string> deviceOps;
+
+    // Determine the actions this device supports
+    if (!device->getAttr("actions", deviceOpAttr)) {
+        log(NOTICE, "Character::mindActuateOp Attempt to actuate something not a device");
+        return;
+    }
+
+    if (!deviceOpAttr.isList()) {
+        log(ERROR, "Character::mindActuateOp device has non list operations list");
+        return;
+    }
+    const ListType & deviceOpList = deviceOpAttr.asList();
+    if (deviceOpList.empty()) {
+        log(ERROR, "Character::mindActuateOp device operation list is empty");
+        return;
+    }
+    ListType::const_iterator J = deviceOpList.begin();
+    ListType::const_iterator Jend = deviceOpList.end();
+    assert(J != Jend);
+
+    for (; J != Jend; ++J) {
+        if (!(*J).isString()) {
+            log(ERROR, "Character::mindActuateOp device has non string in operations list");
+        } else {
+            deviceOps.insert((*J).String());
+        }
+    }
+
+    if (op_type.empty()) {
+        op_type = deviceOpList.front().asString();
+    } else if (deviceOps.find(op_type) == deviceOps.end()) {
+        error(op, "Actuate op is not permitted by device", res, getId());
+        return;
+    }
+
+    debug(std::cout << "Actuating device " << device->getType()
+                    << " with " << op_type << " action."
+                    << std::endl << std::flush;);
+
+    Root obj = Atlas::Objects::Factories::instance()->createObject(op_type);
+    if (!obj.isValid()) {
+        log(ERROR,
+            String::compose("Character::mindActuateOperation Unknown op type "
+                            "\"%1\" requested by \"%2\" device.",
+                            op_type, device->getType()));
+        return;
+    }
+    Operation rop = smart_dynamic_cast<Operation>(obj);
+    if (!rop.isValid()) {
+        log(ERROR, String::compose("Character::mindActuateOperation Op type "
+                                   "\"%1\" requested by %2 device, "
+                                   "but it is not an operation type",
+                                   op_type, device->getType()));
+        // FIXME Think hard about how this error is reported. Would the error
+        // make it back to the client if we made an error response?
+        return;
+    }
+
+    rop->setTo(device->getId());
+
+    res.push_back(rop);
+
+    // Sight sight;
+    // sight->setArgs1(rop);
+    // res.push_back(sight);
 }
 
 /// \brief Filter a Attack operation coming from the mind
@@ -738,18 +867,19 @@ void Character::mindUseOperation(const Operation & op, OpVector & res)
         return;
     }
 
-    if (m_rightHandWield == 0) {
+    EntityProperty * rhw = getSpecificProperty<EntityProperty>(RIGHT_HAND_WIELD);
+    if (rhw == 0) {
+        error(op, "Character::mindUseOp No tool wielded.", res, getId());
+        return;
+    }
+
+    Entity * tool = rhw->data().get();
+    if (tool == 0) {
         error(op, "Character::mindUseOp No tool wielded.", res, getId());
         return;
     }
     // FIXME Get a tool id from the op attributes?
 
-    Entity * tool = m_rightHandWield.get();
-    if (tool == 0) {
-        error(op, "Character::mindUseOp Tool does not exist.", res, getId());
-        return;
-    }
-
     Element toolOpAttr;
     std::set<std::string> toolOps;
     std::string op_type;
@@ -1179,22 +1309,6 @@ void Character::mindSetOperation(const Operation & op, OpVector & res)
     res.push_back(op);
 }
 
-/// \brief Filter a Sight operation coming from the mind
-///
-/// @param op The operation to be filtered.
-/// @param res The filtered result is returned here.
-void Character::mindSightOperation(const Operation & op, OpVector & res)
-{
-}
-
-/// \brief Filter a Sound operation coming from the mind
-///
-/// @param op The operation to be filtered.
-/// @param res The filtered result is returned here.
-void Character::mindSoundOperation(const Operation & op, OpVector & res)
-{
-}
-
 /// \brief Filter a Combine operation coming from the mind
 ///
 /// @param op The operation to be filtered.
@@ -1275,14 +1389,6 @@ void Character::mindDivideOperation(const Operation & op, OpVector & res)
     res.push_back(op);
 }
 
-/// \brief Filter a Get operation coming from the mind
-///
-/// @param op The operation to be filtered.
-/// @param res The filtered result is returned here.
-void Character::mindGetOperation(const Operation & op, OpVector & res)
-{
-}
-
 /// \brief Filter a Imaginary operation coming from the mind
 ///
 /// @param op The operation to be filtered.
@@ -1293,22 +1399,6 @@ void Character::mindImaginaryOperation(const Operation & op, OpVector & res)
     res.push_back(op);
 }
 
-/// \brief Filter a Info operation coming from the mind
-///
-/// @param op The operation to be filtered.
-/// @param res The filtered result is returned here.
-void Character::mindInfoOperation(const Operation & op, OpVector & res)
-{
-}
-
-/// \brief Filter a Nourish operation coming from the mind
-///
-/// @param op The operation to be filtered.
-/// @param res The filtered result is returned here.
-void Character::mindNourishOperation(const Operation & op, OpVector & res)
-{
-}
-
 /// \brief Filter a Talk operation coming from the mind
 ///
 /// @param op The operation to be filtered.
@@ -1391,37 +1481,13 @@ void Character::mindTouchOperation(const Operation & op, OpVector & res)
     res.push_back(s);
 }
 
-/// \brief Filter a Appearance operation coming from the mind
-///
-/// @param op The operation to be filtered.
-/// @param res The filtered result is returned here.
-void Character::mindAppearanceOperation(const Operation & op, OpVector & res)
-{
-}
-
-/// \brief Filter a Disappearance operation coming from the mind
-///
-/// @param op The operation to be filtered.
-/// @param res The filtered result is returned here.
-void Character::mindDisappearanceOperation(const Operation & op, OpVector & res)
-{
-}
-
-
-/// \brief Filter a Error operation coming from the mind
-///
-/// @param op The operation to be filtered.
-/// @param res The filtered result is returned here.
-void Character::mindErrorOperation(const Operation & op, OpVector & res)
-{
-}
-
 /// \brief Filter any other operation coming from the mind
 ///
 /// @param op The operation to be filtered.
 /// @param res The filtered result is returned here.
 void Character::mindOtherOperation(const Operation & op, OpVector & res)
 {
+    log(WARNING, String::compose("Passing %1 op from mind through to world.", op->getParents().front()));
     op->setTo(getId());
     res.push_back(op);
 }
@@ -1567,13 +1633,67 @@ void Character::mind2body(const Operation & op, OpVector & res)
                                    op->getParents().front()));
         return;
     }
-    if (!op->isDefaultFutureSeconds() && op->getClassNo() != OP_TICK) {
+    if (!op->isDefaultFutureSeconds() && op->getClassNo() != Atlas::Objects::Operation::TICK_NO) {
         log(ERROR, String::compose("Operation \"%1\" from mind with "
                                    "FUTURE_SECONDS set.",
                                    op->getParents().front()));
     }
-    OpNo otype = op->getClassNo();
-    OP_SWITCH(op, otype, res, mind)
+    OpNo op_no = op->getClassNo();
+    switch (op_no) {
+        case Atlas::Objects::Operation::COMBINE_NO:
+            mindCombineOperation(op, res);
+            break;
+        case Atlas::Objects::Operation::CREATE_NO:
+            mindCreateOperation(op, res);
+            break;
+        case Atlas::Objects::Operation::DELETE_NO:
+            mindDeleteOperation(op, res);
+            break;
+        case Atlas::Objects::Operation::DIVIDE_NO:
+            mindDivideOperation(op, res);
+            break;
+        case Atlas::Objects::Operation::IMAGINARY_NO:
+            mindImaginaryOperation(op, res);
+            break;
+        case Atlas::Objects::Operation::LOOK_NO:
+            mindLookOperation(op, res);
+            break;
+        case Atlas::Objects::Operation::MOVE_NO:
+            mindMoveOperation(op, res);
+            break;
+        case Atlas::Objects::Operation::SET_NO:
+            mindSetOperation(op, res);
+            break;
+        case Atlas::Objects::Operation::TALK_NO:
+            mindTalkOperation(op, res);
+            break;
+        case Atlas::Objects::Operation::TOUCH_NO:
+            mindTouchOperation(op, res);
+            break;
+        case Atlas::Objects::Operation::USE_NO:
+            mindUseOperation(op, res);
+            break;
+        case Atlas::Objects::Operation::WIELD_NO:
+            mindWieldOperation(op, res);
+            break;
+        default:
+            if (op_no == Atlas::Objects::Operation::ACTUATE_NO) {
+                mindActuateOperation(op, res);
+            } else if (op_no == Atlas::Objects::Operation::ATTACK_NO) {
+                mindAttackOperation(op, res);
+            } else if (op_no == Atlas::Objects::Operation::EAT_NO) {
+                mindEatOperation(op, res);
+            } else if (op_no == Atlas::Objects::Operation::SETUP_NO) {
+                mindSetupOperation(op, res);
+            } else if (op_no == Atlas::Objects::Operation::TICK_NO) {
+                mindTickOperation(op, res);
+            } else if (op_no == Atlas::Objects::Operation::UPDATE_NO) {
+                mindUpdateOperation(op, res);
+            } else {
+                mindOtherOperation(op, res);
+            }
+            break;
+    }
 }
 
 /// \brief Filter operations from the world to the mind
