@@ -15,7 +15,7 @@
 // along with this program; if not, write to the Free Software Foundation,
 // Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 
-// $Id: Entity.h,v 1.96 2007-12-04 00:04:00 alriddoch Exp $
+// $Id: Entity.h,v 1.102 2008-03-26 01:34:16 alriddoch Exp $
 
 #ifndef RULESETS_ENTITY_H
 #define RULESETS_ENTITY_H
@@ -27,14 +27,10 @@
 
 #include "common/BaseWorld.h"
 
-#include <sigc++/connection.h>
-
 #include <iostream>
 
 class Motion;
 
-typedef std::map<std::string, PropertyBase *> PropertyDict;
-
 /// \brief Classes that model in world entities
 ///
 /// These classes are used to model all in world entities or objects.
@@ -56,8 +52,6 @@ class Entity : public LocatedEntity {
   protected:
     /// Motion behavoir of this entity
     Motion * m_motion;
-    /// Map of properties
-    PropertyDict m_properties;
     /// Map of operation handlers
     HandlerMap m_operationHandlers;
 
@@ -98,13 +92,9 @@ class Entity : public LocatedEntity {
     /// \brief Reset the update flags
     void clearUpdateFlags() { m_update_flags = 0; }
 
-    virtual bool hasAttr(const std::string & name) const;
-    virtual bool getAttr(const std::string & name,
-                         Atlas::Message::Element &) const;
     virtual void setAttr(const std::string & name,
                          const Atlas::Message::Element &);
 
-    virtual PropertyBase * getProperty(const std::string & name) const;
     void setProperty(const std::string & name, PropertyBase * prop);
 
     void installHandler(int, Handler);
@@ -114,17 +104,48 @@ class Entity : public LocatedEntity {
     virtual void addToMessage(Atlas::Message::MapType &) const;
     virtual void addToEntity(const Atlas::Objects::Entity::RootEntity &) const;
 
+    virtual void ActuateOperation(const Operation &, OpVector &);
+    virtual void AppearanceOperation(const Operation &, OpVector &);
+    virtual void AttackOperation(const Operation &, OpVector &);
+    virtual void CombineOperation(const Operation &, OpVector &);
+    virtual void CreateOperation(const Operation &, OpVector &);
+    virtual void DeleteOperation(const Operation &, OpVector &);
+    virtual void DisappearanceOperation(const Operation &, OpVector &);
+    virtual void DivideOperation(const Operation &, OpVector &);
+    virtual void EatOperation(const Operation &, OpVector &);
+    virtual void ImaginaryOperation(const Operation &, OpVector &);
+    virtual void LookOperation(const Operation &, OpVector &);
+    virtual void MoveOperation(const Operation &, OpVector &);
+    virtual void NourishOperation(const Operation &, OpVector &);
+    virtual void SetOperation(const Operation &, OpVector &);
+    virtual void SetupOperation(const Operation &, OpVector &);
+    virtual void SightOperation(const Operation &, OpVector &);
+    virtual void SoundOperation(const Operation &, OpVector &);
+    virtual void TalkOperation(const Operation &, OpVector &);
+    virtual void TickOperation(const Operation &, OpVector &);
+    virtual void TouchOperation(const Operation &, OpVector &);
+    virtual void UpdateOperation(const Operation &, OpVector &);
+    virtual void WieldOperation(const Operation &, OpVector &);
+
     virtual void externalOperation(const Operation & op);
     virtual void operation(const Operation &, OpVector &);
 
+    void callOperation(const Operation &, OpVector &);
+
+    virtual void onContainered();
+
     /// Signal indicating that this entity has been changed
     sigc::signal<void> updated;
 
-    /// Signal indicating that this entity has changed its LOC
+    /// Single shot signal indicating that this entity has changed its LOC
     sigc::signal<void> containered;
 
-    /// Signal connections to be removed after firing
-    std::list<sigc::connection> containered_oneshots;
+    /// \brief Signal emitted when this entity is removed from the server
+    ///
+    /// Note that this is usually well before the object is actually deleted
+    /// and marks the conceptual destruction of the concept this entity
+    /// represents, not the destruction of this object.
+    sigc::signal<void> destroyed;
 };
 
 inline std::ostream & operator<<(std::ostream& s, Location& v)
