@@ -15,18 +15,17 @@
 // along with this program; if not, write to the Free Software Foundation,
 // Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 
-// $Id: EntityPropertyFactory.h,v 1.1 2007-01-27 16:35:37 alriddoch Exp $
+// $Id: EntityPropertyFactory.h,v 1.4 2008-01-13 01:32:55 alriddoch Exp $
 
 #ifndef RULESETS_ENTITY_PROPERTY_FACTORY_H
 #define RULESETS_ENTITY_PROPERTY_FACTORY_H
 
-#include "common/types.h"
 #include "common/PropertyFactory.h"
 
 /// \brief Factory class template to create Property objects which require
 /// a pointer to their entity
 template <class T>
-class EntityPropertyBuilder : public PropertyFactory {
+class EntityPropertyFactory : public PropertyKit {
   public:
     virtual PropertyBase * newProperty(Entity *);
 };
