@@ -15,7 +15,7 @@
 // along with this program; if not, write to the Free Software Foundation,
 // Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 
-// $Id: Movement.h,v 1.34 2007-09-22 15:40:18 alriddoch Exp $
+// $Id: Movement.h,v 1.35 2008-01-13 01:32:55 alriddoch Exp $
 
 #ifndef RULESETS_MOVEMENT_H
 #define RULESETS_MOVEMENT_H
@@ -23,7 +23,7 @@
 #include "physics/Vector3D.h"
 #include "physics/Quaternion.h"
 
-#include "common/types.h"
+#include <Atlas/Objects/ObjectsFwd.h>
 
 class Entity;
 class Location;
@@ -78,7 +78,7 @@ class Movement {
     /// how the Entity is moving.
     /// @param new_location Location data about the entity once movement has
     /// changed.
-    virtual Operation generateMove(const Location & new_location) = 0;
+    virtual Atlas::Objects::Operation::RootOperation generateMove(const Location & new_location) = 0;
 };
 
 #endif // RULESETS_MOVEMENT_H
