@@ -15,6 +15,8 @@
 // along with this program; if not, write to the Free Software Foundation,
 // Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 
+// $Id: Pedestrian.cpp,v 1.83 2007-09-22 15:46:14 alriddoch Exp $
+
 #include "Pedestrian.h"
 
 #include "Entity.h"
@@ -37,6 +39,9 @@ using Atlas::Objects::Entity::Anonymous;
 
 static const bool debug_flag = false;
 
+/// \brief Constructor
+///
+/// @param body the Entity this Movement is tracking.
 Pedestrian::Pedestrian(Entity & body) : Movement(body)
 {
 }
@@ -51,9 +56,9 @@ double Pedestrian::getTickAddition(const Point3D & coordinates,
     // This may seem a little weird. Everything is handled in squares to
     // reduce the number of square roots that have to be calculated. In
     // this case only one is required.
-    double basic_square_distance = velocity.sqrMag()
-                                   * consts::square_basic_tick;
     if (m_targetPos.isValid()) {
+        double basic_square_distance = velocity.sqrMag()
+                                       * consts::square_basic_tick;
         double square_distance = squareDistance(coordinates, m_targetPos);
         debug( std::cout << "basic_distance: " << basic_square_distance
                          << std::endl << std::flush;);
@@ -77,7 +82,7 @@ double Pedestrian::getTickAddition(const Point3D & coordinates,
 /// @return 1 if no update was made, or 0 otherwise
 int Pedestrian::getUpdatedLocation(Location & return_location)
 {
-    const double & current_time = m_body.m_world->getTime();
+    const double & current_time = BaseWorld::instance().getTime();
     double time_diff = current_time - m_body.m_location.timeStamp();
 
     if (!updateNeeded(m_body.m_location)) {
@@ -125,11 +130,13 @@ int Pedestrian::getUpdatedLocation(Location & return_location)
         if (mode_attr.isString()) {
             mode = mode_attr.String();
         } else {
-            log(ERROR, String::compose("Mode on entity is a %1 in Pedestrain::getUpdatedLocation", Element::typeName(mode_attr.getType())).c_str());
+            log(ERROR, String::compose("MODE on entity is a \"%1\" "
+                                       "in Pedestrain::getUpdatedLocation.",
+                                       Element::typeName(mode_attr.getType())));
         }
     }
 
-    float z = m_body.m_world->constrainHeight(new_location.m_loc, new_location.m_pos,
+    float z = BaseWorld::instance().constrainHeight(new_location.m_loc, new_location.m_pos,
                                               mode);
     debug(std::cout << "Height adjustment " << z << " " << new_location.m_pos.z()
                     << std::endl << std::flush;);
@@ -141,7 +148,7 @@ int Pedestrian::getUpdatedLocation(Location & return_location)
     return 0;
 }
 
-Operation Pedestrian::generateMove(Location & new_location)
+Operation Pedestrian::generateMove(const Location & new_location)
 {
     // Create move operation
     Move moveOp;
