@@ -15,11 +15,11 @@
 // along with this program; if not, write to the Free Software Foundation,
 // Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 
+// $Id: Py_BBox.cpp,v 1.14 2007-01-12 12:38:06 alriddoch Exp $
+
 #include "Py_BBox.h"
 #include "Py_Vector3D.h"
 
-#include "common/log.h"
-
 static PyObject * BBox_sqr_bounding_radius(PyBBox * self)
 {
     float square_radius = 0;
@@ -37,7 +37,7 @@ static PyMethodDef BBox_methods[] = {
 static void BBox_dealloc(PyBBox * self)
 {
     self->box.~BBox();
-    PyMem_DEL(self);
+    PyObject_Free(self);
 }
 
 static PyObject * BBox_getattr(PyBBox *self, char *name)
@@ -61,11 +61,13 @@ static PyObject * BBox_getattr(PyBBox *self, char *name)
 static int BBox_setattr(PyBBox *self, char *name, PyObject *v)
 {
     if (!PyVector3D_Check(v)) {
-        PyErr_SetString(PyExc_TypeError, "BBox setattr must take tuple of floats, or ints");
+        PyErr_SetString(PyExc_TypeError, "BBox setattr must take a Vector");
+        return -1;
     }
     PyVector3D * vec = (PyVector3D *)v;
     if (!vec->coords.isValid()) {
-        log(ERROR, "BBox.setattr() vector is not set.");
+        PyErr_SetString(PyExc_TypeError, "BBox setattr must take a valid Vector");
+        return -1;
     }
     const Vector3D & vector = vec->coords;
     if (strcmp(name, "near_point") == 0) {
