@@ -15,19 +15,24 @@
 // along with this program; if not, write to the Free Software Foundation,
 // Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 
+// $Id: Py_Location.h,v 1.17 2007-12-07 01:19:16 alriddoch Exp $
+
 #ifndef RULESETS_PY_LOCATION_H
 #define RULESETS_PY_LOCATION_H
 
 #include <Python.h>
 
+class LocatedEntity;
 class Location;
-class Entity;
 
 /// \brief Wrapper for Location in Python
+/// \ingroup PythonWrappers
 typedef struct {
     PyObject_HEAD
+    /// \brief Location object handled by this wrapper
     Location * location;
-    Entity * owner;
+    /// \brief Entiy object that the Location object is a member of
+    LocatedEntity * owner;
 } PyLocation;
 
 extern PyTypeObject PyLocation_Type;
