@@ -15,6 +15,8 @@
 // along with this program; if not, write to the Free Software Foundation,
 // Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 
+// $Id: Py_Map.cpp,v 1.46 2007-01-12 12:38:06 alriddoch Exp $
+
 #include "Py_Map.h"
 #include "Py_Location.h"
 #include "Py_Thing.h"
@@ -38,9 +40,10 @@ static PyObject * Map_find_by_location(PyMap * self, PyObject * args)
         return NULL;
     }
 #endif // NDEBUG
-    double radius;
     PyObject * where_obj;
-    if (!PyArg_ParseTuple(args, "Od", &where_obj, &radius)) {
+    double radius;
+    char * type;
+    if (!PyArg_ParseTuple(args, "Ods", &where_obj, &radius, &type)) {
         return NULL;
     }
     if (!PyLocation_Check(where_obj)) {
@@ -49,7 +52,7 @@ static PyObject * Map_find_by_location(PyMap * self, PyObject * args)
     }
     PyLocation * where = (PyLocation *)where_obj;
     MemEntityVector res = self->m_map->findByLocation(*where->location,
-                                                          radius);
+                                                      radius, type);
     PyObject * list = PyList_New(res.size());
     if (list == NULL) {
         return NULL;
@@ -98,24 +101,6 @@ static PyObject * Map_find_by_type(PyMap * self, PyObject * py_what)
     return list;
 }
 
-static PyObject * Map_look_id(PyMap * self)
-{
-#ifndef NDEBUG
-    if (self->m_map == NULL) {
-        PyErr_SetString(PyExc_AssertionError, "NULL Map in Map.look_id");
-        return NULL;
-    }
-#endif // NDEBUG
-    Operation op = self->m_map->lookId();
-    if (!op.isValid()) {
-        Py_INCREF(Py_None);
-        return Py_None;
-    }
-    PyOperation * py_op = newPyOperation();
-    py_op->operation = op;
-    return (PyObject *)py_op;
-}
-
 static PyObject * Map_updateAdd(PyMap * self, PyObject * args)
 {
 #ifndef NDEBUG
@@ -283,7 +268,6 @@ static PyObject * Map_delete_hooks_append(PyMap * self, PyObject * py_method)
 static PyMethodDef Map_methods[] = {
     {"find_by_location",    (PyCFunction)Map_find_by_location,    METH_VARARGS},
     {"find_by_type",        (PyCFunction)Map_find_by_type,        METH_O},
-    {"look_id",             (PyCFunction)Map_look_id,             METH_NOARGS},
     {"add",                 (PyCFunction)Map_updateAdd,           METH_VARARGS},
     {"delete",              (PyCFunction)Map_delete,              METH_O},
     {"get",                 (PyCFunction)Map_get,                 METH_O},
@@ -297,7 +281,7 @@ static PyMethodDef Map_methods[] = {
 
 static void Map_dealloc(PyMap *self)
 {
-    PyMem_DEL(self);
+    PyObject_Free(self);
 }
 
 static PyObject * Map_getattr(PyMap *self, char *name)
