@@ -15,6 +15,8 @@
 // along with this program; if not, write to the Free Software Foundation,
 // Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 
+// $Id: Py_Operation.cpp,v 1.59 2007-07-30 18:12:51 alriddoch Exp $
+
 #include "Py_Operation.h"
 #include "Py_RootEntity.h"
 #include "Py_Oplist.h"
@@ -323,7 +325,11 @@ static PyObject* Operation_get_name(PyOperation * self)
  * Operation sequence methods.
  */
 
-static int Operation_seq_length(PyOperation * self)
+#if PY_VERSION_HEX < 0x02050000
+typedef int Py_ssize_t;
+#endif
+
+static Py_ssize_t Operation_seq_length(PyOperation * self)
 {
 #ifndef NDEBUG
     if (!self->operation.isValid()) {
@@ -334,7 +340,7 @@ static int Operation_seq_length(PyOperation * self)
     return self->operation->getArgs().size();
 } 
 
-static PyObject * Operation_seq_item(PyOperation * self, int item)
+static PyObject * Operation_seq_item(PyOperation * self, Py_ssize_t item)
 {
 #ifndef NDEBUG
     if (!self->operation.isValid()) {
@@ -467,15 +473,20 @@ static PyNumberMethods Operation_num = {
         0
 };
 
+#if PY_MINOR_VERSION < 5
+#define lenfunc inquiry
+#define ssizeargfunc intargfunc
+#endif
+
 /*
  * Operation sequence methods structure.
  */
 
 static PySequenceMethods Operation_seq = {
-    (inquiry)Operation_seq_length,      /* sq_length */
-    NULL,                               /*  sq_concat */
+    (lenfunc)Operation_seq_length,      /* sq_length */
+    NULL,                               /* sq_concat */
     NULL,                               /* sq_repeat */
-    (intargfunc)Operation_seq_item,     /* sq_item */
+    (ssizeargfunc)Operation_seq_item,   /* sq_item */
     NULL,                               /* sq_slice */
     NULL,                               /* sq_ass_item */
     NULL                                /* sq_ass_slice */
@@ -527,7 +538,7 @@ PyMethodDef ConstRootOperation_methods[] = {
 static void Operation_dealloc(PyOperation *self)
 {
     self->operation.~RootOperation();
-    PyMem_DEL(self);
+    PyObject_Free(self);
 }
 
 static inline PyObject * findMethod(PyOperation * self, char * name)
@@ -585,7 +596,7 @@ static int Operation_setattr(PyOperation *self, char *name, PyObject *v)
 #endif // NDEBUG
     if (strcmp(name, "from_") == 0) {
         PyObject * thing_id = PyObject_GetAttrString(v, "id");
-        if ((thing_id == NULL) || (!PyString_Check(thing_id))) {
+        if (thing_id == NULL || !PyString_Check(thing_id)) {
             PyErr_SetString(PyExc_TypeError, "invalid from");
             if (thing_id != NULL) {
                 Py_DECREF(thing_id);
@@ -598,7 +609,7 @@ static int Operation_setattr(PyOperation *self, char *name, PyObject *v)
     }
     if (strcmp(name, "to") == 0) {
         PyObject * thing_id = PyObject_GetAttrString(v, "id");
-        if ((thing_id == NULL) || (!PyString_Check(thing_id))) {
+        if (thing_id == NULL || !PyString_Check(thing_id)) {
             PyErr_SetString(PyExc_TypeError, "invalid to");
             if (thing_id != NULL) {
                 Py_DECREF(thing_id);
