@@ -15,6 +15,8 @@
 // along with this program; if not, write to the Free Software Foundation,
 // Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 
+// $Id: Py_Oplist.cpp,v 1.31 2007-04-01 20:55:27 alriddoch Exp $
+
 #include "Py_Operation.h"
 #include "Py_Oplist.h"
 
@@ -53,7 +55,7 @@ static void Oplist_dealloc(PyOplist *self)
     if (self->ops != NULL) {
         delete self->ops;
     }
-    PyMem_DEL(self);
+    PyObject_Free(self);
 }
 
 static PyObject * Oplist_getattr(PyOplist *self, char *name)
@@ -116,7 +118,15 @@ static int Oplist_num_coerce(PyObject ** self, PyObject ** other)
     //return -1;
 }
 
-static int Oplist_seq_length(PyOplist * self)
+#if PY_MINOR_VERSION < 5
+#define lenfunc inquiry
+#endif
+
+#if PY_VERSION_HEX < 0x02050000
+typedef int Py_ssize_t;
+#endif
+
+static Py_ssize_t Oplist_seq_length(PyOplist * self)
 {
 #ifndef NDEBUG
     if (self->ops == NULL) {
@@ -127,14 +137,18 @@ static int Oplist_seq_length(PyOplist * self)
     return self->ops->size();
 } 
 
+#if PY_MINOR_VERSION < 5
+#define lenfunc inquiry
+#endif
+
 static PyMappingMethods Oplist_as_mapping = {
-    (inquiry)Oplist_seq_length,      /* mp_length */
+    (lenfunc)Oplist_seq_length,      /* mp_length */
     NULL,
     NULL
 };
 
 static PySequenceMethods Oplist_as_sequence = {
-    (inquiry)Oplist_seq_length,      /* sq_length */
+    (lenfunc)Oplist_seq_length,      /* sq_length */
     NULL,                            /* sq_concat */
     NULL,                            /* sq_repeat */
     NULL,                            /* sq_item */
