@@ -15,6 +15,8 @@
 // along with this program; if not, write to the Free Software Foundation,
 // Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 
+// $Id: Py_Point3D.cpp,v 1.13 2007-07-30 18:12:51 alriddoch Exp $
+
 #include "Py_Point3D.h"
 
 #include "Py_Vector3D.h"
@@ -49,10 +51,18 @@ static PyObject * Point3D_distance(PyPoint3D * self, PyPoint3D * other)
     return PyFloat_FromDouble(distance(self->coords, other->coords));
 }
 
+static PyObject * Point3D_is_valid(PyPoint3D * self)
+{
+    PyObject * ret = self->coords.isValid() ? Py_True : Py_False;
+    Py_INCREF(ret);
+    return ret;
+}
+
 static PyMethodDef Point3D_methods[] = {
     {"mag",             (PyCFunction)Point3D_mag,              METH_NOARGS},
     {"unit_vector_to",  (PyCFunction)Point3D_unit_vector_to,   METH_O},
     {"distance",        (PyCFunction)Point3D_distance,         METH_O},
+    {"is_valid",        (PyCFunction)Point3D_is_valid,         METH_NOARGS},
     {NULL,              NULL}           /* sentinel */
 };
 
@@ -155,7 +165,7 @@ static int Point3D_init(PyPoint3D * self, PyObject * args, PyObject * kwds)
             break;
         case 1:
             clist = PyTuple_GetItem(args, 0);
-            if ((!PyList_Check(clist)) || (PyList_Size(clist) != 3)) {
+            if (!PyList_Check(clist) || PyList_Size(clist) != 3) {
                 PyErr_SetString(PyExc_TypeError, "Point3D() from single value must a list 3 long");
                 return -1;
             }
