@@ -15,19 +15,23 @@
 // along with this program; if not, write to the Free Software Foundation,
 // Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 
+// $Id: Py_Quaternion.h,v 1.11 2007-07-03 01:22:47 alriddoch Exp $
+
 #ifndef RULESETS_PY_QUATERNION_H
 #define RULESETS_PY_QUATERNION_H
 
 #include <Python.h>
 
-#include <physics/Quaternion.h>
+#include "physics/Quaternion.h"
 
 /// \brief Wrapper for Quaternion in Python
 ///
 /// Uses in-place construction to embed full C++ object into what is
 /// basically a C structure.
+/// \ingroup PythonWrappers
 typedef struct {
     PyObject_HEAD
+    /// \brief Quaternion object handled by this wrapper
     Quaternion rotation;
 } PyQuaternion;
 
