@@ -1,5 +1,5 @@
 // Cyphesis Online RPG Server and AI Engine
-// Copyright (C) 2000 Alistair Riddoch
+// Copyright (C) 2006 Alistair Riddoch
 //
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
@@ -15,6 +15,8 @@
 // along with this program; if not, write to the Free Software Foundation,
 // Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 
+// $Id: Py_Statistics.cpp,v 1.18 2007-07-30 18:12:51 alriddoch Exp $
+
 #include "Py_Statistics.h"
 
 #include "Py_Thing.h"
@@ -22,8 +24,6 @@
 
 #include "Task.h"
 
-#include "common/log.h"
-
 static PyMethodDef Statistics_methods[] = {
     {NULL,          NULL}           /* sentinel */
 };
@@ -35,6 +35,9 @@ static void Statistics_dealloc(PyStatistics *self)
 
 static PyObject * Statistics_getattro(PyStatistics *self, PyObject *pn)
 {
+    // We use getattro rather than the simpler getattr because otherwise
+    // overriding of scripts does not work correctly. Statistics objects
+    // in game inherit directly from this class.
     char * name = PyString_AS_STRING(pn);
 #ifndef NDEBUG
     if (self->m_entity == NULL) {
@@ -81,7 +84,7 @@ static int Statistics_setattro(PyStatistics *self, PyObject *pn, PyObject *v)
 
 static int Statistics_compare(PyStatistics *self, PyStatistics *other)
 {
-    if ((self->m_entity == NULL) || (other->m_entity == NULL)) {
+    if (self->m_entity == NULL || other->m_entity == NULL) {
         PyErr_SetString(PyExc_AssertionError, "NULL entity in Statistics.compare");
         return -1;
     }
@@ -105,7 +108,7 @@ static int Statistics_init(PyStatistics * self, PyObject * args, PyObject * kwd)
     }
 
     if (!PyEntity_Check(entity)) {
-        log(ERROR, "Arg to statistics constructor is not an entity");
+        PyErr_SetString(PyExc_TypeError, "Arg to Statistics must be an entity.");
         return -1;
     }
     PyCharacter * character = (PyCharacter *)entity;
