@@ -15,6 +15,8 @@
 // along with this program; if not, write to the Free Software Foundation,
 // Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 
+// $Id: Py_Task.cpp,v 1.16 2007-07-30 18:12:51 alriddoch Exp $
+
 #include "Py_Task.h"
 
 #include "Py_Thing.h"
@@ -108,7 +110,7 @@ static PyMethodDef Task_methods[] = {
 static void Task_dealloc(PyTask *self)
 {
     Py_XDECREF(self->Task_attr);
-    PyMem_DEL(self);
+    PyObject_Free(self);
 }
 
 static PyObject * Task_getattr(PyTask *self, char *name)
@@ -183,7 +185,7 @@ static int Task_setattr(PyTask *self, char *name, PyObject *v)
 
 static int Task_compare(PyTask *self, PyTask *other)
 {
-    if ((self->m_task == NULL) || (other->m_task == NULL)) {
+    if (self->m_task == NULL || other->m_task == NULL) {
         PyErr_SetString(PyExc_AssertionError, "NULL Task in Task.compare");
         return -1;
     }
