@@ -15,7 +15,7 @@
 // along with this program; if not, write to the Free Software Foundation,
 // Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 
-// $Id: Py_Thing.cpp,v 1.64 2007-12-03 20:40:55 alriddoch Exp $
+// $Id: Py_Thing.cpp,v 1.70 2008-01-05 14:05:06 alriddoch Exp $
 
 #include "Py_Thing.h"
 #include "Py_Object.h"
@@ -32,7 +32,7 @@
 
 #include "common/log.h"
 #include "common/Property.h"
-#include "common/inheritance.h"
+#include "common/TypeNode.h"
 
 using Atlas::Message::Element;
 using Atlas::Message::MapType;
@@ -189,9 +189,6 @@ static PyObject * Entity_getattr(PyEntity *self, char *name)
         PyErr_SetString(PyExc_AttributeError, name);
         return NULL;
     }
-    if (strcmp(name, "id") == 0) {
-        return (PyObject *)PyString_FromString(self->m_entity->getId().c_str());
-    }
     if (strcmp(name, "type") == 0) {
         PyObject * list = PyList_New(0);
         if (list == NULL) {
@@ -208,18 +205,17 @@ static PyObject * Entity_getattr(PyEntity *self, char *name)
         loc->owner = self->m_entity;
         return (PyObject *)loc;
     }
-    if (strcmp(name, "world") == 0) {
-        PyWorld * world = newPyWorld();
-        world->world = &BaseWorld::instance();
-        return (PyObject *)world;
-    }
     if (strcmp(name, "contains") == 0) {
+        if (self->m_entity->m_contains == 0) {
+            Py_INCREF(Py_None);
+            return Py_None;
+        }
         PyObject * list = PyList_New(0);
         if (list == NULL) {
             return NULL;
         }
-        LocatedEntitySet::const_iterator I = self->m_entity->m_contains.begin();
-        LocatedEntitySet::const_iterator Iend = self->m_entity->m_contains.end();
+        LocatedEntitySet::const_iterator I = self->m_entity->m_contains->begin();
+        LocatedEntitySet::const_iterator Iend = self->m_entity->m_contains->end();
         for (; I != Iend; ++I) {
             LocatedEntity * child = *I;
             PyObject * wrapper = wrapEntity(child);
@@ -255,11 +251,6 @@ static PyObject * Entity_getattr(PyEntity *self, char *name)
             return Py_None;
         }
     }
-    const MapType & attrs = entity->getAttributes();
-    MapType::const_iterator I = attrs.find(name);
-    if (I != attrs.end()) {
-        return MessageElement_asPyObject(I->second);
-    }
     return Py_FindMethod(self->m_methods, (PyObject *)self, name);
 }
 
