@@ -15,6 +15,8 @@
 // along with this program; if not, write to the Free Software Foundation,
 // Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 
+// $Id: Py_Vector3D.cpp,v 1.36 2007-07-30 18:12:51 alriddoch Exp $
+
 #include "Py_Vector3D.h"
 
 #include "Py_Quaternion.h"
@@ -315,7 +317,7 @@ static int Vector3D_init(PyVector3D * self, PyObject * args, PyObject * kwds)
             break;
         case 1:
             clist = PyTuple_GetItem(args, 0);
-            if ((!PyList_Check(clist)) || (PyList_Size(clist) != 3)) {
+            if (!PyList_Check(clist) || PyList_Size(clist) != 3) {
                 PyErr_SetString(PyExc_TypeError, "Vector3D() from single value must a list 3 long");
                 return -1;
             }
