@@ -15,19 +15,23 @@
 // along with this program; if not, write to the Free Software Foundation,
 // Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 
+// $Id: Py_Vector3D.h,v 1.17 2007-07-03 01:22:47 alriddoch Exp $
+
 #ifndef RULESETS_PY_VECTOR3D_H
 #define RULESETS_PY_VECTOR3D_H
 
 #include <Python.h>
 
-#include <physics/Vector3D.h>
+#include "physics/Vector3D.h"
 
 /// \brief Wrapper for Vector3D in Pyton
 ///
 /// Uses in-place construction to embed full C++ object into what is
 /// basically a C structure.
+/// \ingroup PythonWrappers
 typedef struct {
     PyObject_HEAD
+    /// \brief Vector3D object handled by this wrapper
     Vector3D coords;
 } PyVector3D;
 
