@@ -15,7 +15,7 @@
 // along with this program; if not, write to the Free Software Foundation,
 // Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 
-// $Id: Py_World.cpp,v 1.34 2007-01-12 12:38:08 alriddoch Exp $
+// $Id: Py_World.cpp,v 1.36 2008-01-05 00:05:29 alriddoch Exp $
 
 #include "Py_World.h"
 #include "Py_WorldTime.h"
@@ -27,34 +27,22 @@
 
 static PyObject * World_get_time(PyWorld *self)
 {
-#ifndef NDEBUG
-    if (self->world == NULL) {
-        PyErr_SetString(PyExc_AssertionError,"invalid world object");
-        return NULL;
-    }
-#endif // NDEBUG
     PyWorldTime * wtime = newPyWorldTime();
     if (wtime == NULL) {
         return NULL;
     }
-    wtime->time = new WorldTime((int)self->world->getTime());
+    wtime->time = new WorldTime((int)BaseWorld::instance().getTime());
     wtime->own = true;
     return (PyObject *)wtime;
 }
 
 static PyObject * World_get_object(PyWorld *self, PyObject * id)
 {
-#ifndef NDEBUG
-    if (self->world == NULL) {
-        PyErr_SetString(PyExc_AssertionError,"invalid world object");
-        return NULL;
-    }
-#endif // NDEBUG
     if (!PyString_CheckExact(id)) {
         PyErr_SetString(PyExc_TypeError, "World.get_object must be string");
         return NULL;
     }
-    Entity * ent = self->world->getEntity(PyString_AsString(id));
+    Entity * ent = BaseWorld::instance().getEntity(PyString_AsString(id));
     if (ent == NULL) {
         Py_INCREF(Py_None);
         return Py_None;
@@ -82,11 +70,10 @@ static PyObject * World_getattr(PyWorld *self, char *name)
 static int World_compare(PyWorld * self, PyObject * other)
 {
     if (PyWorld_Check(other)) {
-        PyWorld * other_world = (PyWorld *)other;
-        return (self->world == other_world->world) ? 0 : 1;
+        return 0;
     } else if (PyEntity_Check(other)) {
         PyEntity * other_entity = (PyEntity *)other;
-        return (&self->world->m_gameWorld == other_entity->m_entity) ? 0 : 1;
+        return (&BaseWorld::instance().m_gameWorld == other_entity->m_entity) ? 0 : 1;
     }
     return -1;
 }
