@@ -15,6 +15,8 @@
 // along with this program; if not, write to the Free Software Foundation,
 // Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 
+// $Id: PythonArithmeticScript.h,v 1.5 2006-12-24 17:18:55 alriddoch Exp $
+
 #ifndef RULESETS_PYTHON_ARITHMETIC_SCRIPT_H
 #define RULESETS_PYTHON_ARITHMETIC_SCRIPT_H
 
@@ -25,14 +27,16 @@
 /// This base class allows scripts to override attribute requests
 class PythonArithmeticScript : public ArithmeticScript {
   protected:
+    /// \brief Python instance object implementing the script
     struct _object * m_script;
   public:
-    PythonArithmeticScript(struct _object *);
+    PythonArithmeticScript(struct _object * script);
     virtual ~PythonArithmeticScript();
 
+    /// \brief Accessor for python instance object implementing the script
     struct _object * script() const { return m_script; }
 
-    virtual int attribute(const std::string &, float &);
+    virtual int attribute(const std::string & name, float & val);
 };
 
 #endif // RULESETS_PYTHON_ARITHMETIC_SCRIPT_H
