@@ -15,6 +15,8 @@
 // along with this program; if not, write to the Free Software Foundation,
 // Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 
+// $Id: PythonScript.h,v 1.16 2007-12-02 23:49:07 alriddoch Exp $
+
 #ifndef RULESETS_PYTHON_SCRIPT_H
 #define RULESETS_PYTHON_SCRIPT_H
 
@@ -22,11 +24,10 @@
 
 #include "PythonWrapper.h"
 
-class Entity;
-
 /// \brief Base Script class for Python scripts
 class PythonScript : public PythonWrapper {
   protected:
+    /// \brief Python instance object which implements the script for an entity
     PyObject * scriptObject;
   public:
     PythonScript(PyObject * object, PyObject * wrapper);
