@@ -15,7 +15,7 @@
 // along with this program; if not, write to the Free Software Foundation,
 // Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 
-// $Id: Python_API.cpp,v 1.172 2007-12-04 00:07:34 alriddoch Exp $
+// $Id: Python_API.cpp,v 1.175 2008-01-05 00:05:29 alriddoch Exp $
 
 #include "Python.h"
 
@@ -385,15 +385,7 @@ static PyObject * location_new(PyObject * self, PyObject * args)
         }
     
         if (PyWorld_Check(refO)) {
-            PyWorld * ref = (PyWorld*)refO;
-#ifndef NDEBUG
-            if (ref->world == NULL) {
-                PyErr_SetString(PyExc_AssertionError, "Parent world is invalid");
-                if (decrefO) { Py_DECREF(refO); }
-                return NULL;
-            }
-#endif // NDEBUG
-            ref_ent = &ref->world->m_gameWorld;
+            ref_ent = &BaseWorld::instance().m_gameWorld;
         } else if (PyMind_Check(refO)) {
             PyMind * ref = (PyMind*)refO;
 #ifndef NDEBUG
@@ -1057,10 +1049,6 @@ void init_python_api()
     PyObject * _const = PyModule_New("const");
     PyDict_SetItemString(common_dict, "const", _const);
 
-    o = PyInt_FromLong(0);
-    PyObject_SetAttrString(_const, "server_python", o);
-    Py_DECREF(o);
-
     o = PyInt_FromLong(consts::debug_level);
     PyObject_SetAttrString(_const, "debug_level", o);
     Py_DECREF(o);
@@ -1113,6 +1101,9 @@ void init_python_api()
     }
     PyModule_AddObject(server, "WorldTime", (PyObject *)&PyWorldTime_Type);
 
+    PyWorld * world = newPyWorld();
+    PyModule_AddObject(server, "world", (PyObject *)world);
+
     PyObject * rules = Py_InitModule("rulesets", no_methods);
     if (rules == NULL) {
         log(CRITICAL, "Python init failed to create rules module");
