@@ -15,12 +15,12 @@
 // along with this program; if not, write to the Free Software Foundation,
 // Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 
-// $Id: Task.h,v 1.16 2006-12-10 17:53:52 alriddoch Exp $
+// $Id: Task.h,v 1.17 2008-01-13 01:32:55 alriddoch Exp $
 
 #ifndef RULESETS_TASK_H
 #define RULESETS_TASK_H
 
-#include "common/types.h"
+#include "common/OperationRouter.h"
 
 #include <string>
 
