@@ -15,7 +15,7 @@
 // along with this program; if not, write to the Free Software Foundation,
 // Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 
-// $Id: Thing.cpp,v 1.224 2007-12-02 23:49:07 alriddoch Exp $
+// $Id: Thing.cpp,v 1.228 2008-01-26 17:43:22 alriddoch Exp $
 
 #include "Thing.h"
 
@@ -61,7 +61,9 @@ using Atlas::Objects::Entity::RootEntity;
 static const bool debug_flag = false;
 
 /// \brief Constructor for physical or tangiable entities.
-Thing::Thing(const std::string & id, long intId) : Thing_parent(id, intId)
+Thing::Thing(const std::string & id, long intId) :
+       Identified(id, intId),
+       Thing_parent(id, intId)
 {
     m_motion = new Motion(*this);
 }
@@ -328,8 +330,10 @@ void Thing::checkVisibility(const Point3D & old_pos, OpVector & res)
     this_ent->setId(getId());
     this_ent->setStamp(m_seq);
 
-    LocatedEntitySet::const_iterator I = m_location.m_loc->m_contains.begin();
-    LocatedEntitySet::const_iterator Iend = m_location.m_loc->m_contains.end();
+    assert(m_location.m_loc != 0);
+    assert(m_location.m_loc->m_contains != 0);
+    LocatedEntitySet::const_iterator I = m_location.m_loc->m_contains->begin();
+    LocatedEntitySet::const_iterator Iend = m_location.m_loc->m_contains->end();
     for(; I != Iend; ++I) {
         float old_dist = squareDistance((*I)->m_location.pos(), old_pos),
               new_dist = squareDistance((*I)->m_location.pos(), m_location.pos()),
@@ -473,9 +477,6 @@ void Thing::updateProperties(const Operation & op, OpVector & res) const
     PropertyDict::const_iterator J;
     PropertyDict::const_iterator Jend = m_properties.end();
 
-    MapType::const_iterator K;
-    MapType::const_iterator Kend = m_attributes.end();
-
     for (; I != Iend; ++I) {
         const std::string & attr = I->first;
         debug(std::cout << "  " << attr << std::endl << std::flush;);
@@ -485,14 +486,8 @@ void Thing::updateProperties(const Operation & op, OpVector & res) const
             // Dump the property value into the Sight(Set()) arg
             J->second->add(attr, set_arg);
         } else {
-            K = m_attributes.find(attr);
-            if (K != Kend) {
-                // Copy the attribute into the Sight(Set()) arg
-                set_arg->setAttr(attr, K->second);
-            } else {
-                error(op, String::compose("Got update for non-existant attribute or property \"%1\"",
-                                          attr), res, getId());
-            }
+            error(op, String::compose("Got update for non-existant property "
+                                      "\"%1\"", attr), res, getId());
         }
     }
 
