@@ -15,7 +15,7 @@
 // along with this program; if not, write to the Free Software Foundation,
 // Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 
-// $Id: World.cpp,v 1.111 2007-12-03 23:18:52 alriddoch Exp $
+// $Id: World.cpp,v 1.115 2008-01-26 17:43:22 alriddoch Exp $
 
 #include "World.h"
 
@@ -65,9 +65,11 @@ using Atlas::Objects::smart_dynamic_cast;
 typedef enum { ROCK = 0, SAND = 1, GRASS = 2, SILT = 3, SNOW = 4} Surface;
 
 /// \brief Constructor for the World entity
-World::World(const std::string & id, long intId) : World_parent(id, intId),
-             m_terrain(*new Mercator::Terrain(Mercator::Terrain::SHADED)),
-             m_tileShader(*new Mercator::TileShader)
+World::World(const std::string & id, long intId) :
+       Identified(id, intId),
+       World_parent(id, intId),
+           m_terrain(*new Mercator::Terrain(Mercator::Terrain::SHADED)),
+           m_tileShader(*new Mercator::TileShader)
 {
     m_properties["terrain"] = new TerrainProperty(m_terrain, m_modifiedTerrain,
                                                   m_modifiedTerrain, a_terrain);
@@ -178,7 +180,10 @@ void World::EatOperation(const Operation & op, OpVector & res)
 
 void World::LookOperation(const Operation & op, OpVector & res)
 {
+    // We must be the top level entity
     assert(m_location.m_loc == 0);
+    // We must contains something, or where the hell did the look come from?
+    assert(m_contains != 0);
     // Let the worldrouter know we have been looked at.
 
     debug(std::cout << "World::Operation(Look)" << std::endl << std::flush;);
@@ -189,7 +194,7 @@ void World::LookOperation(const Operation & op, OpVector & res)
         return;
     }
 
-    // Pass entity to addPerceptive
+    // Register the entity with the world router as perceptive.
     BaseWorld::instance().addPerceptive(from);
 
     Sight s;
@@ -200,20 +205,23 @@ void World::LookOperation(const Operation & op, OpVector & res)
 
     // FIXME integrate setting terrain with setting contains.
 
-    std::list<std::string> & contlist = sarg->modifyContains();
-    contlist.clear();
-    LocatedEntitySet::const_iterator Iend = m_contains.end();
-    for (LocatedEntitySet::const_iterator I = m_contains.begin(); I != Iend; ++I) {
-        float fromSquSize = (*I)->m_location.squareBoxSize();
-        float dist = squareDistance((*I)->m_location, from->m_location);
-        float view_factor = fromSquSize / dist;
-        if (view_factor > consts::square_sight_factor) {
-            contlist.push_back((*I)->getId());
+    if (m_contains != 0) {
+        std::list<std::string> & contlist = sarg->modifyContains();
+        contlist.clear();
+        LocatedEntitySet::const_iterator Iend = m_contains->end();
+        LocatedEntitySet::const_iterator I = m_contains->begin();
+        for (; I != Iend; ++I) {
+            float fromSquSize = (*I)->m_location.squareBoxSize();
+            float dist = squareDistance((*I)->m_location, from->m_location);
+            float view_factor = fromSquSize / dist;
+            if (view_factor > consts::square_sight_factor) {
+                contlist.push_back((*I)->getId());
+            }
+        }
+        if (contlist.empty()) {
+            debug(std::cout << "WARNING: contains empty." << std::endl << std::flush;);
+            sarg->removeAttr("contains");
         }
-    }
-    if (contlist.empty()) {
-        debug(std::cout << "WARNING: contains empty." << std::endl << std::flush;);
-        sarg->removeAttr("contains");
     }
 
     s->setTo(op->getFrom());
