@@ -7,14 +7,8 @@ from Quaternion import Quaternion
 from common import const
 from types import *
 
-if const.server_python:
-    from world.physics.Vector3D import Vector3D
-    from mind.BaseMind import BaseMind
-else:
-    from Vector3D import Vector3D
-    from cyphesis.Thing import Thing
-    from server import WorldTime
-    BaseMind = Thing
+from Vector3D import Vector3D
+from cyphesis.Thing import Thing
 
 from mind.Memory import Memory
 from mind.Knowledge import Knowledge
@@ -35,7 +29,7 @@ def get_dict_func(self, func_str, func_undefined):
         func=func_undefined
     return func
 
-class NPCMind(BaseMind):
+class NPCMind(Thing):
     """Mind class for most mobile entities in the game.
 
     An NPCMind object is associated with all NPC and similar entities on a
