@@ -5,6 +5,7 @@ import sys
 #All types of minds uses these goals
 from mind.goals.common.move import *
 from mind.goals.common.misc_goal import *
+from mind.goals.common.trigger import *
 
 # Only humanoids use these goals
 from mind.goals.humanoid.fire import *
@@ -16,3 +17,4 @@ from mind.goals.humanoid.construction import *
 
 # Only animals use these goals
 from mind.goals.animal.herd import *
+from mind.goals.animal.domestic import *
