@@ -169,7 +169,7 @@ class spot_something(Goal):
         Goal.__init__(self, "spot a thing",
                       self.do_I_have,
                       [self.do])
-        if type(what) == types.ListType:
+        if isinstance(what, list):
             self.what = what
         else:
             self.what = [ what ]
@@ -691,3 +691,23 @@ class hireling_transaction(transaction):
         res.append(Operation("talk",Entity(say="I will help you out until sundown today.")))
         self.irrelevant=1
         return res
+
+######################## ACTUATION (Operate device) #######################
+
+class activate_device(Goal):
+    def __init__(self, what):
+        Goal.__init__(self, "activate a thing",
+                      self.activated,
+                      [spot_something(what), self.activate_focus])
+        self.what=what
+        self.vars=["what"]
+    def activated(self, me):
+        return False
+    def activate_focus(self, me):
+        print "Activating ", self.what
+        something=me.get_knowledge('focus', self.what)
+        assert(something)
+        if me.map.get(something) == None:
+           me.remove_knowledge('focus', self.what)
+           return
+        return Operation('actuate', Operation('chop', Entity(something)))
