@@ -47,6 +47,9 @@ add_word('lumber','#lumber_noun1')
 add_word('ham','#ham_noun1')
 add_word('coin','#coin_noun1')
 add_word('deed','#deed_noun1')
+add_word('shirt','#shirt_noun1')
+add_word('cloak','#cloak_noun1')
+add_word('trousers','#trousers_noun1')
 add_word('services','#services_noun1')
 add_word('buy','#buy_verb1')
 add_word('hire','#hire_verb1')
@@ -61,6 +64,14 @@ add_word('execute','#execute_verb1')
 add_word('shovel','#shovel_noun1')
 add_word('tinderbox','#tinderbox_noun1')
 add_word('pickaxe','#pickaxe_noun1')
+add_word('bowl','#bowl_noun1')
+add_word('pole','#pole_noun1')
+add_word('hammer','#hammer_noun1')
+add_word('bottle','#bottle_noun1')
+add_word('cleaver','#cleaver_noun1')
+add_word('trowel','#trowel_noun1')
+add_word('scythe','#scythe_noun1')
+add_word('bucksaw','#bucksaw_noun1')
 
 #CHEAT!: temporary thing
 add_word('build home','#build_home_verb0')
@@ -114,6 +125,7 @@ def add_vso_word(words,index):
 add_vso_word('own','#own_verb1')
 add_vso_word('learn','#learn_verb1')
 add_vso_word('price','#price_verb1')
+add_vso_word('list','#list_verb1')
 
 #>This is for verbs like the above which require a predicate
 # know pig price 5
@@ -255,9 +267,10 @@ def convert_english_to_interlinguish(me, say_entity):
         say=say_entity.say
     except AttributeError:
         return 0
-    name_begin=me.name+", "
-    if say[:len(name_begin)]==name_begin:
-        say=say[len(name_begin):]
+    if hasattr(me,'name'):
+        name_begin=me.name+", "
+        if say[:len(name_begin)]==name_begin:
+            say=say[len(name_begin):]
     match=importance_pattern.match(say)
     if match:
         sub=word2node.get(string.lower(match.group(1)))
