@@ -1,7 +1,10 @@
 #This file is distributed under the terms of the GNU General Public license.
 #Copyright (C) 1999 Aloril (See the file COPYING for details).
 
-import whrandom
+try:
+  from random import *
+except ImportError:
+  from whrandom import *
 from common import log,const
 
 fertility_age=const.basic_tick*30
