@@ -1,7 +1,7 @@
 #This file is distributed under the terms of the GNU General Public license.
 #Copyright (C) 2001 Al Riddoch (See the file COPYING for details).
 
-from world.objects.Thing import Thing
+from cyphesis.Thing import Thing
 from atlas import *
 from Vector3D import Vector3D
 from Point3D import Point3D
