@@ -2,7 +2,7 @@
 #Copyright (C) 2005 Erik Hjortsberg (See the file COPYING for details).
 
 from atlas import *
-from world.objects.Thing import Thing
+from cyphesis.Thing import Thing
 from common import log,const
 from Vector3D import Vector3D
 try:
@@ -20,22 +20,13 @@ When digging at a grave, skeleton parts will be created. We might want to add so
 def create_skeletonpart(self, op):
     retops = Message()
     newloc=self.location.copy()
-    newloc.velocity=Vector3D(0,0,0)
+    newloc.velocity=Vector3D()
     items = ['skull', 'ribcage', 'arm', 'pelvis', 'thigh', 'shin']
     item = items[randint(0,5)]
     newloc.coordinates = newloc.coordinates + Vector3D(uniform(-1,1), uniform(-1,1), uniform(-1,1))
     retops = retops + Operation("create", Entity(name=item,parents=[item],location=newloc.copy()), to=self)
     return retops
 
-class Gravestone_stylish(Thing):
+class Gravestone(Thing):
     def dig_operation(self, op):
-        return create_skeletonpart(self, op)    
-
-class Gravestone_rounded(Thing):
-    def dig_operation(self, op):
-        return create_skeletonpart(self, op)    
-     
-class Gravestone_simple(Thing):
-    def dig_operation(self, op):
-        return create_skeletonpart(self, op)    
-     
+        return create_skeletonpart(self, op)
