@@ -7,6 +7,8 @@ from cyphesis.Thing import Thing
 from Point3D import Point3D
 from BBox import BBox
 
+import server
+
 class Torch(Thing):
     """This is base class for axes, this one just ordinary axe"""
     def ignite_operation(self, op):
@@ -19,7 +21,7 @@ class Torch(Thing):
         to_ = op[0].id
         if not to_:
             return self.error(op,"To is undefined object")
-        return Operation("create",Entity(parents=['fire'],status=fire_child.status, location=Location(self.world.get_object(to_),Point3D(0.0,0.0,0.0))),to=to_)
+        return Operation("create",Entity(parents=['fire'],status=fire_child.status, location=Location(server.world.get_object(to_),Point3D(0.0,0.0,0.0))),to=to_)
     def burn_operation(self, op):
         fire_status = op[0].status
         to_ = op[0].id
