@@ -15,7 +15,7 @@
 // along with this program; if not, write to the Free Software Foundation,
 // Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 
-// $Id: Account.cpp,v 1.154 2007-11-28 20:22:43 alriddoch Exp $
+// $Id: Account.cpp,v 1.159 2008-01-28 23:48:32 alriddoch Exp $
 
 #include "Account.h"
 
@@ -66,10 +66,14 @@ static const bool debug_flag = false;
 /// @param passwd Password for this account
 /// @param id String identifier for this account
 /// @param intId Integer identifier for this account
-Account::Account(Connection * conn, const std::string & uname,
-                 const std::string& passwd, const std::string & id, long intId)
-                 : OOGThing(id, intId), m_connection(conn),
-                   m_username(uname), m_password(passwd)
+Account::Account(Connection * conn,
+                 const std::string & uname,
+                 const std::string & passwd,
+                 const std::string & id,
+                 long intId) :
+         Identified(id, intId),
+         m_connection(conn), m_username(uname),
+                              m_password(passwd)
 {
 }
 
@@ -126,7 +130,7 @@ Entity * Account::addNewCharacter(const std::string & typestr,
         // starts getting hard to tell whether or not they exist.
         m_charactersDict[chr->getIntId()] = chr;
         chr->destroyed.connect(sigc::bind(sigc::mem_fun(this, &Account::characterDestroyed), chr->getIntId()));
-        m_connection->addObject(chr);
+        m_connection->addEntity(chr);
         if (consts::enable_persistence) {
             Persistance::instance()->addCharacter(*this, *chr);
         }
@@ -239,7 +243,8 @@ void Account::addToMessage(MapType & omap) const
         charlist.push_back(I->first);
     }
     omap["characters"] = charlist;
-    BaseEntity::addToMessage(omap);
+    omap["objtype"] = "obj";
+    omap["id"] = getId();
 }
 
 void Account::addToEntity(const Atlas::Objects::Entity::RootEntity & ent) const
@@ -257,7 +262,41 @@ void Account::addToEntity(const Atlas::Objects::Entity::RootEntity & ent) const
         charlist.push_back(I->second->getId());
     }
     ent->setAttr("characters", charlist);
-    BaseEntity::addToEntity(ent);
+    ent->setObjtype("obj");
+    ent->setId(getId());
+}
+
+void Account::operation(const Operation & op, OpVector & res)
+{
+    const OpNo op_no = op->getClassNo();
+    switch (op_no) {
+        case Atlas::Objects::Operation::CREATE_NO:
+            CreateOperation(op, res);
+            break;
+        case Atlas::Objects::Operation::GET_NO:
+            GetOperation(op, res);
+            break;
+        case Atlas::Objects::Operation::IMAGINARY_NO:
+            ImaginaryOperation(op, res);
+            break;
+        case Atlas::Objects::Operation::LOGOUT_NO:
+            LogoutOperation(op, res);
+            break;
+        case Atlas::Objects::Operation::LOOK_NO:
+            LookOperation(op, res);
+            break;
+        case Atlas::Objects::Operation::SET_NO:
+            SetOperation(op, res);
+            break;
+        case Atlas::Objects::Operation::TALK_NO:
+            TalkOperation(op, res);
+            break;
+        case OP_INVALID:
+            break;
+        default:
+            OtherOperation(op, res);
+            break;
+    }
 }
 
 void Account::CreateOperation(const Operation & op, OpVector & res)
@@ -503,3 +542,12 @@ void Account::LookOperation(const Operation & op, OpVector & res)
     }
     error(op, "Unknown look target", res, getId());
 }
+
+void Account::GetOperation(const Operation & op, OpVector & res)
+{
+}
+
+void Account::OtherOperation(const Operation & op, OpVector & res)
+{
+    error(op, "Unknown operation", res);
+}
