@@ -15,22 +15,24 @@
 // along with this program; if not, write to the Free Software Foundation,
 // Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 
-// $Id: Account.h,v 1.54 2006-12-24 17:18:55 alriddoch Exp $
+// $Id: Account.h,v 1.58 2008-01-28 23:48:32 alriddoch Exp $
 
 #ifndef SERVER_ACCOUNT_H
 #define SERVER_ACCOUNT_H
 
-#include "common/OOGThing.h"
+#include "common/Identified.h"
 
 class Connection;
 
+typedef std::map<long, Entity *> EntityDict;
+
 /// \brief This is the base class for storing information about uses who
 /// can use this server.
 ///
 /// The majority of functionality relating to user accounts is encapsulated
 /// here. Sub-classes control privilege levels by implementing
 /// characterError().
-class Account : public OOGThing {
+class Account : public IdentifiedRouter {
   protected:
     /// \brief A store of Character entities belonging to this account
     EntityDict m_charactersDict;
@@ -68,12 +70,16 @@ class Account : public OOGThing {
     virtual void addToMessage(Atlas::Message::MapType &) const;
     virtual void addToEntity(const Atlas::Objects::Entity::RootEntity &) const;
 
+    virtual void operation(const Operation &, OpVector &);
+
     virtual void LogoutOperation(const Operation &, OpVector &);
     virtual void CreateOperation(const Operation &, OpVector &);
     virtual void SetOperation(const Operation &, OpVector &);
     virtual void ImaginaryOperation(const Operation &, OpVector &);
     virtual void TalkOperation(const Operation &, OpVector &);
     virtual void LookOperation(const Operation &, OpVector &);
+    virtual void GetOperation(const Operation &, OpVector &);
+    virtual void OtherOperation(const Operation &, OpVector &);
 
     void addCharacter(Entity *);
 
