@@ -15,7 +15,7 @@
 // along with this program; if not, write to the Free Software Foundation,
 // Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 
-// $Id: Admin.cpp,v 1.117 2007-11-15 02:07:05 alriddoch Exp $
+// $Id: Admin.cpp,v 1.121 2008-01-28 23:48:32 alriddoch Exp $
 
 #include "Admin.h"
 
@@ -55,9 +55,13 @@ using Atlas::Objects::Entity::RootEntity;
 static const bool debug_flag = false;
 
 /// \brief Admin constructor
-Admin::Admin(Connection * conn, const std::string& username,
-             const std::string& passwd, const std::string & id, long intId) :
-             Account(conn, username, passwd, id, intId)
+Admin::Admin(Connection * conn,
+             const std::string & username,
+             const std::string & passwd,
+             const std::string & id,
+             long intId) :
+       Identified(id, intId),
+       Account(conn, username, passwd, id, intId)
 {
 }
 
@@ -174,7 +178,7 @@ void Admin::LogoutOperation(const Operation & op, OpVector & res)
     if (account_id == getId()) {
        Account::LogoutOperation(op, res);
     }
-    BaseEntity * account = m_connection->m_server.getObject(account_id);
+    IdentifiedRouter * account = m_connection->m_server.getObject(account_id);
     if (!account) {
         error(op, "Logout failed", res, getId());
         return;
@@ -209,14 +213,15 @@ void Admin::GetOperation(const Operation & op, OpVector & res)
     if (objtype == "object" || objtype == "obj") {
         long intId = integerId(id);
 
-        const BaseDict & OOGDict = m_connection->m_server.getObjects();
-        BaseDict::const_iterator J = OOGDict.find(intId);
+        const RouterMap & OOGDict = m_connection->m_server.getObjects();
+        RouterMap::const_iterator J = OOGDict.find(intId);
         const EntityDict & worldDict = m_connection->m_server.m_world.getEntities();
         EntityDict::const_iterator K = worldDict.find(intId);
 
         if (J != OOGDict.end()) {
+            IdentifiedRouter * obj = J->second;
             Anonymous info_arg;
-            J->second->addToEntity(info_arg);
+            obj->addToEntity(info_arg);
             info->setArgs1(info_arg);
         } else if (K != worldDict.end()) {
             Anonymous info_arg;
@@ -279,7 +284,7 @@ void Admin::SetOperation(const Operation & op, OpVector & res)
         // Manipulate attributes of existing objects.
     } else if (objtype == "class" || objtype == "op_definition") {
         if (Inheritance::instance().hasClass(id)) {
-            if (EntityFactory::instance()->modifyRule(id, arg) == 0) {
+            if (EntityBuilder::instance()->modifyRule(id, arg) == 0) {
                 Info info;
                 info->setTo(getId());
                 info->setArgs1(arg);
@@ -343,7 +348,7 @@ void Admin::CreateOperation(const Operation & op, OpVector & res)
                   res, getId());
             return;
         }
-        if (EntityFactory::instance()->installRule(id, arg) == 0) {
+        if (EntityBuilder::instance()->installRule(id, arg) == 0) {
             Info info;
             info->setTo(getId());
             info->setArgs1(arg);
