@@ -15,6 +15,8 @@
 // along with this program; if not, write to the Free Software Foundation,
 // Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 
+// $Id: CommSlaveClient.cpp,v 1.4 2006-10-26 00:48:14 alriddoch Exp $
+
 #include "CommSlaveClient.h"
 
 #include "SlaveClientConnection.h"
@@ -24,8 +26,9 @@
 ///
 /// @param svr Reference to the object that manages all socket communication.
 /// @param fd Socket file descriptor
-CommSlaveClient::CommSlaveClient(CommServer & svr, int fd) :
-                 CommClient(svr, fd, *new SlaveClientConnection("local", *this,
+CommSlaveClient::CommSlaveClient(CommServer & svr, int fd,
+                                 const std::string & id) :
+                 CommClient(svr, fd, *new SlaveClientConnection(id, *this,
                                                                 svr.m_server))
 {
 }
