@@ -15,6 +15,8 @@
 // along with this program; if not, write to the Free Software Foundation,
 // Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 
+// $Id: CommSlaveClient.h,v 1.6 2006-12-22 02:14:45 alriddoch Exp $
+
 #ifndef SERVER_COMM_SLAVE_CLIENT_H
 #define SERVER_COMM_SLAVE_CLIENT_H
 
@@ -22,9 +24,10 @@
 
 /// \brief Handle an internet socket connected to a local client for a slave
 /// server.
+/// \ingroup ServerSockets
 class CommSlaveClient : public CommClient {
   public:
-    CommSlaveClient(CommServer & svr, int fd);
+    CommSlaveClient(CommServer & svr, int fd, const std::string & id);
     virtual ~CommSlaveClient();
 
 };
