@@ -15,11 +15,16 @@
 // along with this program; if not, write to the Free Software Foundation,
 // Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 
+// $Id: CommSlaveListener.cpp,v 1.5 2006-10-26 00:48:14 alriddoch Exp $
+
 #include "CommSlaveListener.h"
 
 #include "CommSlaveClient.h"
 #include "CommServer.h"
 
+#include "common/id.h"
+#include "common/log.h"
+
 static const bool debug_flag = false;
 
 /// \brief Constructor for listener socket object.
@@ -35,9 +40,15 @@ CommSlaveListener::~CommSlaveListener()
 
 int CommSlaveListener::create(int asockfd)
 {
-    // FIXME Hmm, no proper ID for this connection.
+    std::string connection_id;
+    if (newId(connection_id) < 0) {
+        log(ERROR, "Unable to accept connection as no ID available");
+        close(asockfd);
+        return -1;
+    }
 
-    CommSlaveClient * newpeer = new CommSlaveClient(m_commServer, asockfd);
+    CommSlaveClient * newpeer = new CommSlaveClient(m_commServer, asockfd,
+                                                    connection_id);
 
     newpeer->setup();
 
