@@ -15,7 +15,7 @@
 // along with this program; if not, write to the Free Software Foundation,
 // Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 
-// $Id: Connection.cpp,v 1.168 2007-11-28 20:22:43 alriddoch Exp $
+// $Id: Connection.cpp,v 1.173 2008-01-28 23:48:32 alriddoch Exp $
 
 #include "Connection.h"
 
@@ -61,9 +61,9 @@ Connection::Connection(CommClient & client,
                        ServerRouting & svr,
                        const std::string & addr,
                        const std::string & id) :
-            OOGThing(id, forceIntegerId(id)), m_obsolete(false),
-                                              m_commClient(client),
-                                              m_server(svr)
+            Identified(id, forceIntegerId(id)), m_obsolete(false),
+                                                m_commClient(client),
+                                                m_server(svr)
 {
     m_server.incClients();
     logEvent(CONNECT, String::compose("%1 - - Connect from %2", id, addr));
@@ -80,8 +80,8 @@ Connection::~Connection()
     
     logEvent(DISCONNECT, String::compose("%1 - - Disconnect", getId()));
 
-    BaseDict::const_iterator Iend = m_objects.end();
-    for (BaseDict::const_iterator I = m_objects.begin(); I != Iend; ++I) {
+    RouterMap::const_iterator Iend = m_objects.end();
+    for (RouterMap::const_iterator I = m_objects.begin(); I != Iend; ++I) {
         removePlayer(I->second, "Disconnect");
     }
 
@@ -119,7 +119,8 @@ Account * Connection::addPlayer(const std::string& username,
 ///
 /// The object being removed may be a player, or another type of object such
 /// as an avatar. If it is an player or other account, a pointer is returned.
-Account * Connection::removePlayer(BaseEntity * obj, const std::string & event)
+Account * Connection::removePlayer(IdentifiedRouter * obj,
+                                   const std::string & event)
 {
     Account * ac = dynamic_cast<Account *>(obj);
     if (ac != 0) {
@@ -160,12 +161,17 @@ Account * Connection::removePlayer(BaseEntity * obj, const std::string & event)
     return 0;
 }
 
-void Connection::addObject(BaseEntity * obj)
+void Connection::addEntity(Entity * ent)
+{
+    addObject(ent);
+    ent->destroyed.connect(sigc::bind(sigc::mem_fun(this,
+                                                    &Connection::objectDeleted),
+                                      ent->getIntId()));
+}
+
+void Connection::addObject(IdentifiedRouter * obj)
 {
     m_objects[obj->getIntId()] = obj;
-    obj->destroyed.connect(sigc::bind(sigc::mem_fun(this,
-                                                    &Connection::objectDeleted),
-                                      obj->getIntId()));
 }
 
 void Connection::removeObject(long id)
@@ -223,12 +229,31 @@ void Connection::operation(const Operation & op, OpVector & res)
     debug(std::cout << "Connection::operation" << std::endl << std::flush;);
     if (!op->hasAttrFlag(Atlas::Objects::Operation::FROM_FLAG)) {
         debug(std::cout << "deliver locally" << std::endl << std::flush;);
-        callOperation(op, res);
+        const OpNo op_no = op->getClassNo();
+        switch (op_no) {
+            case Atlas::Objects::Operation::CREATE_NO:
+                CreateOperation(op, res);
+                break;
+            case Atlas::Objects::Operation::GET_NO:
+                GetOperation(op, res);
+                break;
+            case Atlas::Objects::Operation::LOGIN_NO:
+                LoginOperation(op, res);
+                break;
+            case Atlas::Objects::Operation::LOGOUT_NO:
+                LogoutOperation(op, res);
+                break;
+            case OP_INVALID:
+                break;
+            default:
+                error(op, "Unknown operation", res);
+                break;
+        }
         return;
     }
     const std::string & from = op->getFrom();
     debug(std::cout << "send on to " << from << std::endl << std::flush;);
-    BaseDict::const_iterator I = m_objects.find(integerId(from));
+    RouterMap::const_iterator I = m_objects.find(integerId(from));
     if (I == m_objects.end()) {
         error(op, String::compose("Client \"%1\" op from \"%2\" is from "
                                   "non-existant object.",
@@ -236,13 +261,13 @@ void Connection::operation(const Operation & op, OpVector & res)
               res);
         return;
     }
-    BaseEntity * b_ent = I->second;
-    Entity * ig_ent = dynamic_cast<Entity *>(b_ent);
+    IdentifiedRouter * obj = I->second;
+    Entity * ig_ent = dynamic_cast<Entity *>(obj);
     if (ig_ent == NULL) {
-        b_ent->operation(op, res);
+        obj->operation(op, res);
         return;
     }
-    Character * character = dynamic_cast<Character *>(b_ent);
+    Character * character = dynamic_cast<Character *>(obj);
     if (character != NULL && character->m_externalMind == NULL) {
         debug(std::cout << "Subscribing existing character" << std::endl
                         << std::flush;);
@@ -320,7 +345,7 @@ void Connection::LoginOperation(const Operation & op, OpVector & res)
     EntityDict::const_iterator J = player->getCharacters().begin();
     EntityDict::const_iterator Jend = player->getCharacters().end();
     for (; J != Jend; ++J) {
-        addObject(J->second);
+        addEntity(J->second);
     }
     player->m_connection = this;
     m_server.m_lobby.addAccount(player);
@@ -426,7 +451,7 @@ void Connection::LogoutOperation(const Operation & op, OpVector & res)
         error(op, "Got logout for non numeric entity ID", res);
         return;
     }
-    BaseDict::iterator I = m_objects.find(obj_id);
+    RouterMap::iterator I = m_objects.find(obj_id);
     if (I == m_objects.end()) {
         error(op, String::compose("Got logout for unknown entity ID(%1)",
                                   obj_id),
