@@ -15,20 +15,22 @@
 // along with this program; if not, write to the Free Software Foundation,
 // Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 
-// $Id: Connection.h,v 1.57 2007-12-07 01:19:16 alriddoch Exp $
+// $Id: Connection.h,v 1.62 2008-01-28 23:48:32 alriddoch Exp $
 
 #ifndef SERVER_CONNECTION_H
 #define SERVER_CONNECTION_H
 
-#include "common/OOGThing.h"
+#include "common/Identified.h"
 
-#include <sigc++/connection.h>
+#include <sigc++/trackable.h>
 
 class Account;
 class Character;
 class CommClient;
 class ServerRouting;
 
+typedef std::map<long, IdentifiedRouter *> RouterMap;
+
 /// \brief Class representing connections from a client at the Atlas level.
 ///
 /// This is the first point of dispatch for any operation from the client.
@@ -37,8 +39,8 @@ class ServerRouting;
 /// and any other entities that that are associated with those accounts,
 /// like in-game characters. Clients specify which entity should handle
 /// an operation using the from attribute.
-class Connection : public OOGThing {
-    BaseDict m_objects;
+class Connection : public IdentifiedRouter, virtual public sigc::trackable {
+    RouterMap m_objects;
 
     /// \brief Flag to indicate if this connection has already been
     /// disconnected from the entities associated with it.
@@ -50,7 +52,7 @@ class Connection : public OOGThing {
     bool m_obsolete;
 
     Account * addPlayer(const std::string &, const std::string &);
-    Account * removePlayer(BaseEntity *, const std::string & event);
+    Account * removePlayer(IdentifiedRouter *, const std::string & event);
   protected:
     virtual int verifyCredentials(const Account &,
                                   const Atlas::Objects::Root &) const;
@@ -62,7 +64,8 @@ class Connection : public OOGThing {
                const std::string & addr, const std::string & id);
     virtual ~Connection();
 
-    void addObject(BaseEntity * obj);
+    void addEntity(Entity * ent);
+    void addObject(IdentifiedRouter * obj);
     void removeObject(long id);
     void objectDeleted(long id);
 
