@@ -15,7 +15,7 @@
 // along with this program; if not, write to the Free Software Foundation,
 // Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 
-// $Id: EntityFactory.cpp,v 1.130 2007-12-07 17:42:58 alriddoch Exp $
+// $Id: EntityFactory.cpp,v 1.136 2008-06-03 14:12:56 alriddoch Exp $
 
 #include <Python.h>
 
@@ -27,7 +27,6 @@
 #include "TaskFactory.h"
 #include "ArithmeticFactory.h"
 #include "Persistance.h"
-#include "Persistor.h"
 #include "Player.h"
 
 #include "rulesets/Thing.h"
@@ -60,18 +59,19 @@
 #include <dirent.h>
 #endif // HAS_DIRENT_H
 
-
 using Atlas::Message::Element;
 using Atlas::Message::MapType;
 using Atlas::Message::ListType;
 using Atlas::Objects::Root;
 using Atlas::Objects::Entity::RootEntity;
 
+typedef std::map<std::string, Atlas::Objects::Root> RootDict;
+
 static const bool debug_flag = false;
 
-EntityFactory * EntityFactory::m_instance = NULL;
+EntityBuilder * EntityBuilder::m_instance = NULL;
 
-EntityFactory::EntityFactory(BaseWorld & w) : m_world(w)
+EntityBuilder::EntityBuilder(BaseWorld & w) : m_world(w)
 {
     if (consts::enable_persistence && database_flag) {
         installFactory("world", "game_entity", new ForbiddenThingFactory<World>());
@@ -103,12 +103,12 @@ EntityFactory::EntityFactory(BaseWorld & w) : m_world(w)
     new CorePropertyManager();
 }
 
-EntityFactory::~EntityFactory()
+EntityBuilder::~EntityBuilder()
 {
     delete PropertyManager::instance();
 }
 
-void EntityFactory::initWorld()
+void EntityBuilder::initWorld()
 {
     if (!consts::enable_persistence) {
         return;
@@ -123,10 +123,24 @@ void EntityFactory::initWorld()
         log(CRITICAL, "Its not a world factory");
         return;
     }
-    wft->m_p.persist((World&)m_world.m_gameWorld);
+    // FIXME Persist the new world.
 }
 
-Entity * EntityFactory::newEntity(const std::string & id, long intId,
+/// \brief Build and populate a new entity object.
+///
+/// A factory is found for the type of entity, and invoked to create the object
+/// instance. If the type has a script factory, this is invoked to create the
+/// associates script object which is attached to the entity instance.
+/// The attribute values are then set on the instance, taking into account
+/// the defaults for the class, and those inherited from parent classes, and
+/// the values specified for this instance. The essential location data for
+/// this instance is then set up. The final block of code relating to
+/// persistence is legacy, and should never be invoked.
+/// @param id The string identifier of the new entity.
+/// @param intId The integer identifier of the new entity.
+/// @param type The string specifying the type of entity.
+/// @param attributes A mapping of attribute values to set on the entity.
+Entity * EntityBuilder::newEntity(const std::string & id, long intId,
                                   const std::string & type,
                                   const RootEntity & attributes) const
 {
@@ -137,7 +151,7 @@ Entity * EntityFactory::newEntity(const std::string & id, long intId,
     if (I == m_entityFactories.end()) {
         return 0;
     }
-    FactoryBase * factory = I->second;
+    EntityKit * factory = I->second;
     thing = factory->newPersistantThing(id, intId, &pc);
     if (thing == 0) {
         return 0;
@@ -175,12 +189,12 @@ Entity * EntityFactory::newEntity(const std::string & id, long intId,
     }
     if (thing->m_location.velocity().isValid()) {
         if (attributes->hasAttrFlag(Atlas::Objects::Entity::VELOCITY_FLAG)) {
-            log(ERROR, String::compose("EntityFactory::newEntity(%1, %2): "
+            log(ERROR, String::compose("EntityBuilder::newEntity(%1, %2): "
                                        "Entity has velocity set from the "
                                        "attributes given by the creator",
                                        id, type));
         } else {
-            log(ERROR, String::compose("EntityFactory::newEntity(%1, %2): "
+            log(ERROR, String::compose("EntityBuilder::newEntity(%1, %2): "
                                        "Entity has velocity set from an "
                                        "unknown source", id, type));
         }
@@ -189,12 +203,16 @@ Entity * EntityFactory::newEntity(const std::string & id, long intId,
     if (pc != 0) {
         pc->persist();
         thing->clearUpdateFlags();
+        delete pc;
     }
-    delete pc;
     return thing;
 }
 
-Task * EntityFactory::newTask(const std::string & name, Character & owner) const
+/// \brief Build and populate a new task object.
+///
+/// @param name The name of the task type.
+/// @param owner The character entity that owns the task.
+Task * EntityBuilder::newTask(const std::string & name, Character & owner) const
 {
     TaskFactoryDict::const_iterator I = m_taskFactories.find(name);
     if (I == m_taskFactories.end()) {
@@ -203,7 +221,18 @@ Task * EntityFactory::newTask(const std::string & name, Character & owner) const
     return I->second->newTask(owner);
 }
 
-Task * EntityFactory::activateTask(const std::string & tool,
+/// \brief Build a new task object activated by the described event.
+///
+/// An event is described in terms of the tool type used to cause it,
+/// the type of operation being performed using the tool and the type of
+/// the target object the tool is being used on. If a match is found for
+/// this event, a task object is instanced to track the progress of the
+/// result of the event.
+/// @param tool The type of tool activating the event.
+/// @param op The type of operation being performed with the tool.
+/// @param target The type of entity the operation is being performed on.
+/// @param owner The character entity activating the task.
+Task * EntityBuilder::activateTask(const std::string & tool,
                                    const std::string & op,
                                    const std::string & target,
                                    Character & owner) const
@@ -231,7 +260,7 @@ Task * EntityFactory::activateTask(const std::string & tool,
     return 0;
 }
 
-int EntityFactory::addStatisticsScript(Character & character) const
+int EntityBuilder::addStatisticsScript(Character & character) const
 {
     StatisticsFactoryDict::const_iterator I = m_statisticsFactories.begin();
     if (I == m_statisticsFactories.end()) {
@@ -241,7 +270,8 @@ int EntityFactory::addStatisticsScript(Character & character) const
     return 0;
 }
 
-void EntityFactory::flushFactories()
+/// \brief Clear out all the factory objects owned by the entity builder.
+void EntityBuilder::flushFactories()
 {
     FactoryDict::const_iterator Iend = m_entityFactories.end();
     for (FactoryDict::const_iterator I = m_entityFactories.begin(); I != Iend; ++I) {
@@ -262,8 +292,8 @@ void EntityFactory::flushFactories()
     m_taskFactories.clear();
 }
 
-int EntityFactory::populateEntityFactory(const std::string & class_name,
-                                         FactoryBase * factory,
+int EntityBuilder::populateEntityFactory(const std::string & class_name,
+                                         EntityKit * factory,
                                          const MapType & class_desc)
 {
     // assert(class_name == class_desc->getId());
@@ -354,7 +384,7 @@ int EntityFactory::populateEntityFactory(const std::string & class_name,
     return 0;
 }
 
-int EntityFactory::populateTaskFactory(const std::string & class_name,
+int EntityBuilder::populateTaskFactory(const std::string & class_name,
                                        TaskFactory * factory,
                                        const MapType & class_desc)
 {
@@ -363,7 +393,7 @@ int EntityFactory::populateTaskFactory(const std::string & class_name,
     return 0;
 }
 
-bool EntityFactory::isTask(const std::string & class_name)
+bool EntityBuilder::isTask(const std::string & class_name)
 {
     if (class_name == "task") {
         return true;
@@ -371,12 +401,12 @@ bool EntityFactory::isTask(const std::string & class_name)
     return (m_taskFactories.find(class_name) != m_taskFactories.end());
 }
 
-static void updateChildren(FactoryBase * factory)
+static void updateChildren(EntityKit * factory)
 {
-    std::set<FactoryBase *>::const_iterator I = factory->m_children.begin();
-    std::set<FactoryBase *>::const_iterator Iend = factory->m_children.end();
+    std::set<EntityKit *>::const_iterator I = factory->m_children.begin();
+    std::set<EntityKit *>::const_iterator Iend = factory->m_children.end();
     for (; I != Iend; ++I) {
-        FactoryBase * child_factory = *I;
+        EntityKit * child_factory = *I;
         child_factory->m_attributes = factory->m_attributes;
         MapType::const_iterator J = child_factory->m_classAttributes.begin();
         MapType::const_iterator Jend = child_factory->m_classAttributes.end();
@@ -387,7 +417,7 @@ static void updateChildren(FactoryBase * factory)
     }
 }
 
-int EntityFactory::installTaskClass(const std::string & class_name,
+int EntityBuilder::installTaskClass(const std::string & class_name,
                                     const std::string & parent,
                                     const Root & class_desc)
 {
@@ -472,7 +502,7 @@ int EntityFactory::installTaskClass(const std::string & class_name,
                                    activation_tool));
         return -1;
     }
-    FactoryBase * tool_factory = K->second;
+    EntityKit * tool_factory = K->second;
 
     J = activation.find("operation");
     if (J == act_end || !J->second.isString()) {
@@ -538,7 +568,7 @@ int EntityFactory::installTaskClass(const std::string & class_name,
     return 0;
 }
 
-int EntityFactory::installEntityClass(const std::string & class_name,
+int EntityBuilder::installEntityClass(const std::string & class_name,
                                       const std::string & parent,
                                       const Root & class_desc)
 {
@@ -555,8 +585,8 @@ int EntityFactory::installEntityClass(const std::string & class_name,
                                     " does not exist.", class_name, parent));
         return 1;
     }
-    FactoryBase * parent_factory = I->second;
-    FactoryBase * factory = parent_factory->duplicateFactory();
+    EntityKit * parent_factory = I->second;
+    EntityKit * factory = parent_factory->duplicateFactory();
     if (factory == 0) {
         log(ERROR,
             String::compose("Attempt to install rule \"%1\" which has parent "
@@ -589,7 +619,7 @@ int EntityFactory::installEntityClass(const std::string & class_name,
     return 0;
 }
 
-int EntityFactory::installOpDefinition(const std::string & class_name,
+int EntityBuilder::installOpDefinition(const std::string & class_name,
                                        const std::string & parent,
                                        const Root & class_desc)
 {
@@ -619,7 +649,7 @@ int EntityFactory::installOpDefinition(const std::string & class_name,
     return 0;
 }
 
-int EntityFactory::installRule(const std::string & class_name,
+int EntityBuilder::installRule(const std::string & class_name,
                                const Root & class_desc)
 {
     assert(class_name == class_desc->getId());
@@ -685,7 +715,7 @@ int EntityFactory::installRule(const std::string & class_name,
     return 0;
 }
 
-int EntityFactory::modifyEntityClass(const std::string & class_name,
+int EntityBuilder::modifyEntityClass(const std::string & class_name,
                                      const Root & class_desc)
 {
     assert(class_name == class_desc->getId());
@@ -696,7 +726,7 @@ int EntityFactory::modifyEntityClass(const std::string & class_name,
                                    "entity class \"%1\".", class_name));
         return -1;
     }
-    FactoryBase * factory = I->second;
+    EntityKit * factory = I->second;
     assert(factory != 0);
     
     ScriptFactory * script_factory = factory->m_scriptFactory;
@@ -715,7 +745,7 @@ int EntityFactory::modifyEntityClass(const std::string & class_name,
         // This is non fatal, but nice to know it has happened.
         // This should only happen if the client attempted to modify the
         // type data for a core hard coded type.
-        log(ERROR, String::compose("EntityFactory::modifyEntityClass: \"%1\" "
+        log(ERROR, String::compose("EntityBuilder::modifyEntityClass: \"%1\" "
                                    "modified by client, but has no parent "
                                    "factory.", class_name));
         factory->m_attributes = MapType();
@@ -734,7 +764,7 @@ int EntityFactory::modifyEntityClass(const std::string & class_name,
     return 0;
 }
 
-int EntityFactory::modifyTaskClass(const std::string & class_name,
+int EntityBuilder::modifyTaskClass(const std::string & class_name,
                                    const Root & class_desc)
 {
     assert(class_name == class_desc->getId());
@@ -752,14 +782,14 @@ int EntityFactory::modifyTaskClass(const std::string & class_name,
     return 0;
 }
 
-int EntityFactory::modifyOpDefinition(const std::string & class_name,
+int EntityBuilder::modifyOpDefinition(const std::string & class_name,
                                       const Root & class_desc)
 {
     // Nothing to actually do
     return 0;
 }
 
-int EntityFactory::modifyRule(const std::string & class_name,
+int EntityBuilder::modifyRule(const std::string & class_name,
                               const Root & class_desc)
 {
     assert(class_name == class_desc->getId());
@@ -783,7 +813,7 @@ int EntityFactory::modifyRule(const std::string & class_name,
 ///
 /// Note that a rule cannot yet be installed because it depends on something
 /// that has not yet occured, or a more fatal condition has occured.
-void EntityFactory::waitForRule(const std::string & rulename,
+void EntityBuilder::waitForRule(const std::string & rulename,
                                 const Root & ruledesc,
                                 const std::string & dependent,
                                 const std::string & reason)
@@ -796,7 +826,7 @@ void EntityFactory::waitForRule(const std::string & rulename,
     m_waitingRules.insert(std::make_pair(dependent, rule));
 }
 
-void EntityFactory::getRulesFromFiles(std::map<std::string, Root> & rules)
+void EntityBuilder::getRulesFromFiles(std::map<std::string, Root> & rules)
 {
     std::string filename;
 
@@ -829,7 +859,7 @@ void EntityFactory::getRulesFromFiles(std::map<std::string, Root> & rules)
     ::closedir(rules_dir);
 }
 
-void EntityFactory::installRules()
+void EntityBuilder::installRules()
 {
     std::map<std::string, Root> ruleTable;
 
@@ -864,9 +894,9 @@ void EntityFactory::installRules()
     }
 }
 
-void EntityFactory::installFactory(const std::string & class_name,
+void EntityBuilder::installFactory(const std::string & class_name,
                                    const std::string & parent,
-                                   FactoryBase * factory,
+                                   EntityKit * factory,
                                    Root class_desc)
 {
     assert(factory != 0);
@@ -884,7 +914,7 @@ void EntityFactory::installFactory(const std::string & class_name,
     }
 }
 
-FactoryBase * EntityFactory::getNewFactory(const std::string & parent)
+EntityKit * EntityBuilder::getNewFactory(const std::string & parent)
 {
     FactoryDict::const_iterator I = m_entityFactories.find(parent);
     if (I == m_entityFactories.end()) {
