@@ -15,7 +15,7 @@
 // along with this program; if not, write to the Free Software Foundation,
 // Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 
-// $Id: Peer.cpp,v 1.7 2007-09-22 15:34:05 alriddoch Exp $
+// $Id: Peer.cpp,v 1.10 2008-01-28 23:48:33 alriddoch Exp $
 
 #include "Peer.h"
 
@@ -31,10 +31,14 @@ Peer::Peer(CommClient & client,
            ServerRouting & svr,
            const std::string & addr,
            const std::string & id) :
-      OOGThing(id, forceIntegerId(id)), m_commClient(client), m_server(svr)
+      Identified(id, forceIntegerId(id)), m_commClient(client), m_server(svr)
 {
 }
 
 Peer::~Peer()
 {
 }
+
+void Peer::operation(const Operation &, OpVector &)
+{
+}
