@@ -15,6 +15,8 @@
 // along with this program; if not, write to the Free Software Foundation,
 // Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 
+// $Id: Persistance.cpp,v 1.53 2007-12-07 17:42:59 alriddoch Exp $
+
 #include "Persistance.h"
 
 #include "Admin.h"
@@ -30,6 +32,7 @@
 #include "common/compose.hpp"
 
 using Atlas::Message::MapType;
+using Atlas::Objects::Root;
 
 static const bool debug_flag = false;
 
@@ -49,34 +52,45 @@ Persistance * Persistance::instance()
 
 int Persistance::init()
 {
-    Persistance * p = instance();
-    assert(p != 0);
+    assert(this != 0);
 
-    if (p->m_connection.initConnection(false) != 0) {
-        return -1;
+    if (m_connection.initConnection() != 0) {
+        if (::instance == CYPHESIS) {
+            return DATABASE_CONERR;
+        }
+        if (m_connection.createInstanceDatabase() != 0) {
+            log(ERROR, "Database creation failed.");
+            return DATABASE_CONERR;
+        }
+        if (m_connection.initConnection() != 0) {
+            log(ERROR, "Still couldn't connect.");
+            return DATABASE_CONERR;
+        }
+        log(INFO, String::compose("Auto created database for new instance "
+                                  "\"%1\".", ::instance));
     }
 
-    if (!p->m_connection.registerEntityIdGenerator()) {
+    if (!m_connection.registerEntityIdGenerator()) {
         log(ERROR, "Faled to register Id generator in database.");
-        return -2;
+        return DATABASE_TABERR;
     }
 
-    bool i = p->m_connection.initRule(true);
+    bool i = m_connection.initRule(true);
 
     MapType tableDesc;
     tableDesc["username"] = "                                                                                ";
     tableDesc["password"] = "                                                                                ";
     tableDesc["type"] = "          ";
-    bool j = p->m_connection.registerSimpleTable("accounts", tableDesc);
-    bool k = p->m_connection.registerRelation(p->m_characterRelation,
+    bool j = m_connection.registerSimpleTable("accounts", tableDesc);
+    bool k = m_connection.registerRelation(m_characterRelation,
                                               "accounts",
                                               "entity_ent");
 
-    if (!p->findAccount("admin")) {
+    if (!findAccount("admin")) {
         debug(std::cout << "Bootstraping admin account."
                         << std::endl << std::flush;);
         std::string adminAccountId;
-        long adminAccountIntId = p->m_connection.newId(adminAccountId);
+        long adminAccountIntId = m_connection.newId(adminAccountId);
         if (adminAccountIntId < 0) {
             log(CRITICAL, "Unable to get admin account ID from Database");
             return -2;
@@ -85,7 +99,7 @@ int Persistance::init()
         Admin dummyAdminAccount(0, "admin", consts::defaultAdminPasswordHash,
                                 adminAccountId, adminAccountIntId);
         
-        p->putAccount(dummyAdminAccount);
+        putAccount(dummyAdminAccount);
     }
 
     return (i && j && k) ? 0 : -2;
@@ -93,11 +107,10 @@ int Persistance::init()
 
 void Persistance::shutdown()
 {
-    Persistance * p = m_instance;
-    if (p == NULL) { return; }
-    p->m_connection.shutdownConnection();
-    delete &p->m_connection;
-    delete p;
+    m_connection.shutdownConnection();
+    delete &m_connection;
+    assert(this == m_instance);
+    delete m_instance;
     m_instance = NULL;
 }
 
@@ -145,7 +158,7 @@ Account * Persistance::getAccount(const std::string & name)
     long intId = integerId(id);
     if (intId == -1) {
         dr.clear();
-        log(ERROR, String::compose("Invalid ID \"%1\" for account from database.", id).c_str());
+        log(ERROR, String::compose("Invalid ID \"%1\" for account from database.", id));
         return 0;
     }
     c = dr.field("password");
@@ -203,7 +216,9 @@ void Persistance::registerCharacters(Account & ac,
 
         EntityDict::const_iterator J = worldObjects.find(intId);
         if (J == worldObjects.end()) {
-            log(WARNING, String::compose("Persistance: Got character id \"%1\" from database which does not exist in world", id).c_str());
+            log(WARNING, String::compose("Persistance: Got character id \"%1\" "
+                                         "from database which does not exist "
+                                         "in world.", id));
             continue;
         }
         ac.addCharacter(J->second);
@@ -221,9 +236,9 @@ void Persistance::delCharacter(const std::string & id)
     m_connection.removeRelationRowByOther(m_characterRelation, id);
 }
 
-bool Persistance::getRules(MapType & m)
+bool Persistance::getRules(std::map<std::string, Root> & t)
 {
-    return m_connection.getTable(m_connection.rule(), m);
+    return m_connection.getTable(m_connection.rule(), t);
 }
 
 bool Persistance::clearRules()
