@@ -15,7 +15,7 @@
 // along with this program; if not, write to the Free Software Foundation,
 // Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 
-// $Id: PersistantThingFactory.h,v 1.26 2007-12-07 01:19:16 alriddoch Exp $
+// $Id: PersistantThingFactory.h,v 1.29 2007-12-20 21:07:51 alriddoch Exp $
 
 #ifndef SERVER_THING_FACTORY_H
 #define SERVER_THING_FACTORY_H
@@ -28,11 +28,12 @@ class Entity;
 class ScriptFactory;
 class TypeNode;
 
-template <class T>
-class Persistor;
-
 /// \brief Interface class for connecting a newly created entity to its
 /// persistor
+///
+/// When an entity is newly created, it is necessary to write it to
+/// the persistent store after it has been fully initialised. This
+/// connector allows the call to be made to the persistor.
 class PersistorBase {
   public:
     virtual ~PersistorBase() { }
@@ -40,28 +41,14 @@ class PersistorBase {
     virtual void persist() = 0;
 };
 
-/// \brief Class template for connecting a newly created entity to its
-/// persistor
-template <class T>
-class PersistorConnection : public PersistorBase {
-  private:
-    T & m_t;
-    Persistor<T> & m_p;
-  public:
-    PersistorConnection(T & t, Persistor<T> & p) : m_t(t), m_p(p) { }
-
-    /// Use p to hook up t into the persistance code
-    void persist();
-};
-
 /// \brief Base class for for factories for creating entities
 ///
 /// An Entity consists of an instance of one of a number of C++ classes
 /// optionally with a script. Stores information about default attributes,
 /// script language and class name.
-class FactoryBase {
+class EntityKit {
   protected:
-    FactoryBase();
+    EntityKit();
   public:
     ScriptFactory * m_scriptFactory;
     /// Default attribute values for this class
@@ -71,39 +58,42 @@ class FactoryBase {
     Atlas::Message::MapType m_attributes;
     /// Factory for class from which the class handled by this factory
     /// inherits.
-    FactoryBase * m_parent;
+    EntityKit * m_parent;
     /// Set of factories for classes which inherit from the class handled
     /// by this factory.
-    std::set<FactoryBase *> m_children;
+    std::set<EntityKit *> m_children;
     /// Inheritance type of this class.
     TypeNode * m_type;
 
-    virtual ~FactoryBase();
+    virtual ~EntityKit();
 
     /// \brief Create a new Entity and make it persistent.
     ///
     /// @param id a string giving the identifier of the Entity.
     /// @param intId an integer giving the identifier of the Entity.
     /// @param pb a pointer to the persistor object for the Entity.
-    virtual Entity * newPersistantThing(const std::string & id, long intId, PersistorBase ** pb) = 0;
+    virtual Entity * newPersistantThing(const std::string & id,
+                                        long intId,
+                                        PersistorBase ** pb) = 0;
     /// \brief Add anything required to the entity after it has been created.
     virtual int populate(Entity &) = 0;
     /// \brief Create a copy of this factory.
-    virtual FactoryBase * duplicateFactory() = 0;
+    virtual EntityKit * duplicateFactory() = 0;
 };
 
 template <class T>
-class ThingFactory : public FactoryBase {
+class ThingFactory : public EntityKit {
   protected:
     ThingFactory(ThingFactory<T> & o);
   public:
     ThingFactory();
     virtual ~ThingFactory();
 
-    virtual T * newPersistantThing(const std::string & id, long intId,
+    virtual T * newPersistantThing(const std::string & id,
+                                   long intId,
                                    PersistorBase ** p);
     virtual int populate(Entity &);
-    virtual FactoryBase * duplicateFactory();
+    virtual EntityKit * duplicateFactory();
 };
 
 // How do we make sure the peristance hooks are put in place in a typesafe way
@@ -114,32 +104,31 @@ class ThingFactory : public FactoryBase {
 template <class T>
 class PersistantThingFactory : public ThingFactory<T> {
   protected:
-    PersistantThingFactory(PersistantThingFactory<T> & p) : m_p(p.m_p),
-                                                            m_master(false) { }
+    PersistantThingFactory(PersistantThingFactory<T> & p) { }
   public:
-    Persistor<T> & m_p;
-    const bool m_master;
-
-    PersistantThingFactory() : m_p(* new Persistor<T>()), m_master(true) { }
+    PersistantThingFactory() { }
     virtual ~PersistantThingFactory();
  
-    virtual T * newPersistantThing(const std::string & id, long intId, PersistorBase ** p);
-    virtual FactoryBase * duplicateFactory();
+    virtual T * newPersistantThing(const std::string & id,
+                                   long intId,
+                                   PersistorBase ** p);
+    virtual EntityKit * duplicateFactory();
 };
 
 /// \brief Class template for factories for entity classes which cannot or
 /// should not be instanced
 template <class T>
-class ForbiddenThingFactory : public FactoryBase {
+class ForbiddenThingFactory : public EntityKit {
   public:
-    Persistor<T> & m_p;
-    ForbiddenThingFactory() : m_p(* new Persistor<T>()) { }
+    ForbiddenThingFactory() { }
 
     virtual ~ForbiddenThingFactory();
  
-    virtual T * newPersistantThing(const std::string & id, long intId, PersistorBase ** p);
+    virtual T * newPersistantThing(const std::string & id,
+                                   long intId,
+                                   PersistorBase ** p);
     virtual int populate(Entity &);
-    virtual FactoryBase * duplicateFactory();
+    virtual EntityKit * duplicateFactory();
 };
 
 #endif // SERVER_THING_FACTORY_H
