@@ -15,6 +15,8 @@
 // along with this program; if not, write to the Free Software Foundation,
 // Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 
+// $Id: TaskFactory.cpp,v 1.11 2007-07-29 03:33:35 alriddoch Exp $
+
 #include "server/TaskFactory.h"
 
 #include "server/ScriptFactory.h"
@@ -26,11 +28,16 @@
 #include "rulesets/Character.h"
 
 #include "common/log.h"
+#include "common/compose.hpp"
 
 TaskFactory::~TaskFactory()
 {
 }
 
+/// \brief PythonTaskScriptFactory constructor
+///
+/// @param package name of the package containing the script
+/// @param name name of the type within the package for the script
 PythonTaskScriptFactory::PythonTaskScriptFactory(const std::string & package,
                                                  const std::string & name) :
                                                  m_module(0), m_class(0),
@@ -42,8 +49,7 @@ PythonTaskScriptFactory::PythonTaskScriptFactory(const std::string & package,
     m_module = PyImport_Import(package_name);
     Py_DECREF(package_name);
     if (m_module == NULL) {
-        std::string msg = std::string("Missing python module ") + m_package;
-        log(ERROR, msg.c_str());
+        log(ERROR, String::compose("Missing python module \"%1\"", m_package));
         PyErr_Print();
         return;
     }
@@ -53,16 +59,14 @@ PythonTaskScriptFactory::PythonTaskScriptFactory(const std::string & package,
     classname[0] = toupper(classname[0]);
     m_class = PyObject_GetAttrString(m_module, (char *)classname.c_str());
     if (m_class == NULL) {
-        std::string msg = std::string("Could not find python class ")
-                        + m_package + "." + classname;
-        log(ERROR, msg.c_str());
+        log(ERROR, String::compose("Could not find python class \"%1.%2\"",
+                                   m_package, classname));
         PyErr_Print();
         return;
     }
     if (PyCallable_Check(m_class) == 0) {
-        std::string msg = std::string("Could not instance python class ")
-                        + m_package + "." + classname;
-        log(ERROR, msg.c_str());
+        log(ERROR, String::compose("Could not instance python class \"%1.%2\"",
+                                   m_package, classname));
         Py_DECREF(m_class);
         m_class = 0;
         return;
