@@ -15,7 +15,7 @@
 // along with this program; if not, write to the Free Software Foundation,
 // Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 
-// $Id: WorldRouter.cpp,v 1.221 2007-12-02 23:49:07 alriddoch Exp $
+// $Id: WorldRouter.cpp,v 1.225 2008-01-05 14:05:06 alriddoch Exp $
 
 #include "WorldRouter.h"
 
@@ -30,6 +30,7 @@
 #include "common/globals.h"
 #include "common/random.h"
 #include "common/system.h"
+#include "common/TypeNode.h"
 #include "common/serialno.h"
 #include "common/compose.hpp"
 #include "common/inheritance.h"
@@ -109,7 +110,7 @@ WorldRouter::WorldRouter() : BaseWorld(*new World(consts::rootWorldId,
     m_initTime = tv.tv_sec;
     updateTime(tv.tv_sec, tv.tv_usec);
     m_gameWorld.incRef();
-    EntityFactory::init(*this);
+    EntityBuilder::init(*this);
     m_gameWorld.setType(Inheritance::instance().getType("world"));
     m_eobjects[m_gameWorld.getIntId()] = &m_gameWorld;
     m_perceptives.insert(&m_gameWorld);
@@ -274,8 +275,9 @@ Entity * WorldRouter::addEntity(Entity * ent, bool setup)
     }
     ent->m_location.m_pos.z() = constrainHeight(ent->m_location.m_loc,
                                                 ent->m_location.pos(), mode);
-    bool cont_change = ent->m_location.m_loc->m_contains.empty();
-    ent->m_location.m_loc->m_contains.insert(ent);
+    ent->m_location.m_loc->makeContainer();
+    bool cont_change = ent->m_location.m_loc->m_contains->empty();
+    ent->m_location.m_loc->m_contains->insert(ent);
     ent->m_location.m_loc->incRef();
     if (cont_change) {
         Entity * loc = dynamic_cast<Entity *>(ent->m_location.m_loc);
@@ -319,7 +321,7 @@ Entity * WorldRouter::addNewEntity(const std::string & typestr,
         return 0;
     }
 
-    Entity * ent = EntityFactory::instance()->newEntity(id, intId, typestr, attrs);
+    Entity * ent = EntityBuilder::instance()->newEntity(id, intId, typestr, attrs);
     if (ent == 0) {
         log(ERROR, String::compose("Attempt to create an entity of type \"%1\" "
                                    "but type is unknown or forbidden",
@@ -337,7 +339,7 @@ Entity * WorldRouter::addNewEntity(const std::string & typestr,
 /// @return a pointer to the new task
 Task * WorldRouter::newTask(const std::string & name, Character & owner)
 {
-    Task * task = EntityFactory::instance()->newTask(name, owner);
+    Task * task = EntityBuilder::instance()->newTask(name, owner);
     if (task == 0) {
         log(ERROR, String::compose("Attempt to create a task of type \"%1\" "
                                    "but type is unknown or forbidden", name));
@@ -359,7 +361,7 @@ Task * WorldRouter::activateTask(const std::string & tool,
                                  const std::string & target,
                                  Character & owner)
 {
-    return EntityFactory::instance()->activateTask(tool, op, target, owner);
+    return EntityBuilder::instance()->activateTask(tool, op, target, owner);
 }
 
 /// \brief Remove an entity from the world.
