@@ -15,7 +15,7 @@
 // along with this program; if not, write to the Free Software Foundation,
 // Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 
-// $Id: Creatortest.cpp,v 1.26 2007-12-03 23:29:20 alriddoch Exp $
+// $Id: Creatortest.cpp,v 1.28 2008-01-07 14:35:48 alriddoch Exp $
 
 #include "IGEntityExerciser.h"
 #include "allOperations.h"
@@ -24,6 +24,8 @@
 #include "rulesets/Creator.h"
 #include "rulesets/Python_API.h"
 
+#include "common/TypeNode.h"
+
 #include <cassert>
 
 using Atlas::Message::MapType;
@@ -55,7 +57,6 @@ int main(int argc, char ** argv)
     std::set<std::string> attrNames;
     attrNames.insert("id");
     attrNames.insert("bbox");
-    attrNames.insert("contains");
 
     // Make sure we have all the default attributes
     assert(ee.checkAttributes(attrNames));
